//
//  HPRTFunctionESC.h
//  HPRTPrinter
//
//  Created by midmirror on 16/3/18.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <HPRTSDK/HPRTSDK.h>     //首先需要导入框架

/**
 *  示例类： 如何对ESC-POS指令集进行封装使用。
 *  封装了一些常用的方法。如打印文本、图片、二维码、条形码、页模式打印
 */
@interface HPRTFunctionESC : NSObject

/**
 *  打印条形码
 *
 *  @param justification    page 165. 对齐方式       取值0,1,2 : 左、中、右
 *  @param type             page 339. 取值：(A:0~6),(B:65~73)
 *  @param width            page 355. 取值：(2~6),(68~76)
 *  @param height           page 337. 取值：(1~255)
 *  @param hri_position     page 332. 取值：(0~3),(48~51)
 *  @param barcode          page 339.
 *
 *  @return 生成的条形码十六进制数据
 */
- (NSData *)escPrintBarCodeWithJustification:(int)justification
                                        Type:(int)type
                                       Width:(int)width
                                      Height:(int)height
                                 HRIPosition:(int)hri_position
                                     Barcode:(NSString *)barcode;

/**
 *  打印二维码
 *
 *  @param justification    page 165. 对齐方式       取值0,1,2 : 左、中、右
 *  @param left_margin      page 169. 左间距
 *  @param model            page 552. 二维码样式     取值49,50 : 两种样式
 *  @param size             page 553. 大小          取值1~16
 *  @param correction_level page 555. 纠错等级       取值48~51: Level L,M,Q,H
 *  @param qr_code          page 557. 二维码数据
 *
 *  @return 生成好的十六进制数据
 */
- (NSData *)escPrintQRCodeWithJustification:(int)justification
                                 LeftMargin:(int)left_margin
                                      Model:(int)model
                                       Size:(int)size
                            CorrectionLevel:(int)correction_level
                                     QRCode:(NSString *)qr_code;

/**
 *  页模式打印
 *
 *  @param horizontal
 *  @param vertical
 *  @param width
 *  @param height
 *  @param x_position
 *  @param y_position
 *  @param direction
 *
 *  @return
 */
- (NSData *)escPrintPageWithHorizontal:(int)horizontal
                              Vertical:(int)vertical
                                 Width:(int)width
                                Height:(int)height
                             XPosition:(int)x_position
                             YPosition:(int)y_position
                             Direction:(int)direction;

/**
 *  设置带格式文本
 *
 *  @param justification 对齐方式
 *  @param left_margin   左间距
 *  @param font          是否切换字体
 *  @param emphasize     加粗
 *  @param double_height 倍高
 *  @param double_width  背宽
 *  @param underline     下划线
 */
- (NSData *)escPrintTextWithJustification:(int)justification
                                   Margin:(int)left_margin
                                     Font:(BOOL)font
                                Emphasize:(BOOL)emphasize
                             DoubleHeight:(BOOL)double_height
                              DoubleWidth:(BOOL)double_width
                                Underline:(BOOL)underline
                              ReverseMode:(BOOL)reverse_mode;

@end
