//
//  HPRTHomeVC.m
//
//  Created by midmirror on 16/1/27.
//  Copyright © 2016年 PRT. All rights reserved.
//

#import "HPRTHomeVC.h"
#import "Masonry.h"
#import "HPRTBarcodeVC.h"
#import "HPRTTextVC.h"
#import "HPRTPageVC.h"
#import "HPRTPhotoVC.h"
#import "HPRTConnectVC.h"
#import "HPRTTestPrint.h"

@interface HPRTHomeVC ()

@property(strong,nonatomic,readwrite) NSArray *btnArray;
@property(strong,nonatomic,readwrite) NSDictionary *tableRowDic;
@property(strong,nonatomic,readwrite) UILabel *titleLabel;
@property(assign,nonatomic,readwrite) CGFloat buttonWidth;
@property(assign,nonatomic,readwrite) CGFloat buttonHeight;

@end

@implementation HPRTHomeVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    _tableKit = [MIDTableKit share];
    
    _titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 300, 44)];
    _titleLabel.backgroundColor = [UIColor clearColor];
    _titleLabel.font = [UIFont fontWithName:@"Gurmukhi MN" size:30];
    _titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    _titleLabel.textAlignment = NSTextAlignmentCenter;
    _titleLabel.text = @"HPRT";
    self.navigationItem.titleView = _titleLabel;
    
    self.edgesForExtendedLayout = UIRectEdgeNone;
    
    [[HPRTPrinter share] initPrinter];    //初始化打印机
}

- (void)popAlertViewWithTitle:(NSString *)title Message:(NSString *)message {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.3 splitPercentage:0.3 headColor:headColor buttonColor:nil];
    _popView.footView.backgroundColor = PRTCOLOR_COULD;
    _popView.titleLabel.text = title;
    
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH*0.6, SCREEN_HEIGHT*0.15)];
    label.textColor = [UIColor grayColor];
    label.textAlignment = NSTextAlignmentCenter;
    [_popView.footView addSubview:label];
    label.text = message;
    
    __block MIDPopView *popView = _popView;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
    }];
    
    [_popView show];
}


- (void)viewWillAppear:(BOOL)animated {
    
//    [self startShimmering];
    [self setMainView];
     
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationUserSelectCell:) name:@"NotificationUserSelectCell" object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(setMainView) name:@"HPRTDispatchModeChangeToOffline" object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(startShimmering) name:UIApplicationWillEnterForegroundNotification object:nil];
}

- (void)startShimmering {
//    [_titleLabel startShimmering];
}

- (void)viewWillDisappear:(BOOL)animated {
    
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)notificationUserSelectCell:(NSNotification *)sender {
    
    _tableRowDic = [sender userInfo];
}

#pragma mark Setup View
- (void)setMainView {
    
    _tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    [self.view addSubview:_tableView];
    
    _buttonWidth = [[MIDScreenFit share] getMainButtonWidth];
    _buttonHeight = [[MIDScreenFit share] getMainButtonHeight];
    
    _bluetoothButton = [[UIButton alloc] init];
    [_bluetoothButton addTarget:self action:@selector(popConnectVC) forControlEvents:UIControlEventTouchUpInside];
    _bluetoothButton.layer.borderWidth = 0.5;
    _bluetoothButton.layer.cornerRadius = _buttonHeight/2;
    _bluetoothButton.layer.borderColor = [UIColor whiteColor].CGColor;
    _bluetoothButton.titleLabel.font = [UIFont systemFontOfSize:[[MIDScreenFit share] getFontSize]];
    
    [self setCycleView];
    [self setChangeView];
}

- (void)popConnectVC {
    
    if ([HPRTDispatcher share].currentDispatchMode == DispatchModeOffline) {
        
        HPRTConnectVC *connectVC = [[HPRTConnectVC alloc] init];
        [self presentViewController:connectVC animated:YES completion:^{
            
        }];
        
    }else {
        
        [[HPRTDispatcher share] disConnectCurrentLine];
    }
}

//根据设备型号决定是否展示那个半圆。
- (void)setCycleView {
    
    if (SCREEN_RESOLUTION > iphone5) { //尺寸大于 iPhone5才展示
        
        _headView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT*0.25)];
        _tableView.tableHeaderView = _headView;
        MIDDrawView *cycleView = [[MIDDrawView alloc] init];
        
        [_headView addSubview:cycleView];
        
        CGFloat diameter = [[MIDScreenFit share] getDiameter];
        
        [cycleView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.equalTo(_headView.mas_centerX);
            make.top.equalTo(_headView.mas_top);
            make.size.mas_equalTo(CGSizeMake(diameter, diameter/2));
        }];
        
        [_headView addSubview:_bluetoothButton];
        [_bluetoothButton mas_makeConstraints:^(MASConstraintMaker *make) {
            
            make.centerX.equalTo(_headView);
            make.centerY.equalTo(cycleView.mas_bottom);
            make.size.mas_equalTo(CGSizeMake(_buttonWidth, _buttonHeight));
        }];
        
    }else {
        
        _headView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT*0.2)];
        _tableView.tableHeaderView = _headView;
        [_headView addSubview:_bluetoothButton];
        
        [_bluetoothButton mas_makeConstraints:^(MASConstraintMaker *make) {
            
            make.centerX.equalTo(_headView);
            make.centerY.equalTo(_headView);
            make.size.mas_equalTo(CGSizeMake(_buttonWidth, _buttonHeight));
        }];
    }
}

// 判断是否连接蓝牙，改变视图展示信息
- (void)setChangeView {
    
    UIColor *headColor;
    
    [_bluetoothButton setTitle:@"Connect Printer" forState:UIControlStateNormal];
    
    NSLog(@"dispatchMode:%ld",(long)[HPRTDispatcher share].currentDispatchMode);
    
    UILabel *label = [[UILabel alloc] init];
    [_headView addSubview:label];
    label.textColor = [UIColor whiteColor];
    label.textAlignment = NSTextAlignmentCenter;
    label.font = [UIFont systemFontOfSize:[[MIDScreenFit share] getFontSize]-5];
    [label mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(_headView);
        make.bottom.equalTo(_bluetoothButton.mas_top).offset(-10);
        make.size.mas_equalTo(CGSizeMake(_buttonWidth, _buttonHeight/2));
    }];
    
    switch ([HPRTDispatcher share].currentDispatchMode) {
            
        case DispatchModeOffline:
            
            headColor = PRTCOLOR_GRAY;
            break;
        case DispatchModeBLE:
            
            headColor = PRTCOLOR_ORANGE;
            [_bluetoothButton setTitle:@"Disconnect BLE" forState:UIControlStateNormal];
            label.text = [NSString stringWithFormat:@"%@ Online",[HPRTDispatcher share].bluetoothConnected.name];
            break;
        case DispatchModeWIFI:
            
            headColor = PRTCOLOR_ORANGE;
            [_bluetoothButton setTitle:@"Disconnect Wifi" forState:UIControlStateNormal];
            label.text = @"Wifi Online";
            break;
            
        default:
            break;
    }
    
    self.navigationController.navigationBar.barTintColor = headColor;
    _headView.backgroundColor = headColor;
}

- (void)empty {
    
    _tableRowDic = nil;
}

// 弹出选取图片打印的视图
- (void)popBitmapView {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *buttonColor = [UIColor whiteColor];
    
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor buttonColor:buttonColor];
    
    __block MIDPopView *popView = _popView;
    __block HPRTHomeVC *homeVC = self;
    __block HPRTBitmapFunc *bitmap = [[HPRTBitmapFunc alloc] init];
    
    NSArray *imageArray = @[@[@"logo.jpg",@"pander.jpg",@"emeya.jpg"]];
    //打印黑白二值图像
    [_popView addButtonWithTitle:@"Binary" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
        
        if (homeVC.tableRowDic) {
            int row = [[homeVC.tableRowDic objectForKey:@"row"] intValue];
            NSData *printData = [bitmap generateMonoBitmapDefault:[UIImage imageNamed:imageArray[0][row]]];
            [[HPRTDispatcher share] sendData:printData];
            [homeVC empty];
        }
    }];
    
    //打印经过抖动算法的视觉灰度图
    [_popView addButtonWithTitle:@"Gray" handler:^ (MIDPopViewButton *button) {
        
        [popView hideAnimation];
        
        if (homeVC.tableRowDic) {
            int row = [[homeVC.tableRowDic objectForKey:@"row"] intValue];
            NSData *printData = [bitmap generateDitherBitmapDefault:[UIImage imageNamed:imageArray[0][row]]];
            
            [[HPRTDispatcher share] sendData:printData];
            [homeVC empty];
        }
    }];
    
    [_popView addButtonWithTitle:@"Cancel" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
        
    }];
    
    [_popView show];
    
    _popView.titleLabel.text = @"Print Bitmap";
    
    _tableKit = [[MIDTableKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 DataArray:imageArray TableMode:MIDTableModeBitmap CheckMark:YES];
    [_popView.footView addSubview:_tableKit];
}

#pragma mark Func

- (void)popTextVC {
    
    HPRTTextVC *textVC = [[HPRTTextVC alloc] init];
    [self.navigationController pushViewController:textVC animated:YES];
}

- (void)popBarcodeVC {
    
    HPRTBarcodeVC *barcodeVC = [[HPRTBarcodeVC alloc] init];
    [self.navigationController pushViewController:barcodeVC animated:YES];
}

- (void)popPageVC {
    
    HPRTPageVC *pageVC = [[HPRTPageVC alloc] init];
    [self.navigationController pushViewController:pageVC animated:YES];
}

- (void)popPhotoVC {
    
    HPRTPhotoVC *photoVC = [[HPRTPhotoVC alloc] init];
    [self.navigationController pushViewController:photoVC animated:YES];
}

- (void)didReceiveMemoryWarning {
    
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return 3;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    if (section == 0) {
        return 3;
    }else if(section == 1 ){
        return 5;
    }else {
        return 1;
    }
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"homeCell";
    MIDTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[MIDTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    NSString *appName = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleName"];
    
    NSArray *titleArray = @[@[@"Phrase",@"Receipt",@"Barcode"],@[@"Bitmap",@"Barcode",@"Text",@"Page",@"Photo"],@[appName]];
    NSArray *detailArray = @[@"Direct print text with format",@"Direct print a receipt",@"Direct print some barcode"];

    tableCell.textLabel.text = titleArray[indexPath.section][indexPath.row];
    tableCell.imageView.image = [UIImage imageNamed:titleArray[indexPath.section][indexPath.row]];
    if (indexPath.section == 1) {
        if (indexPath.row > 0) {
            tableCell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        }else {
            tableCell.detailTextLabel.text = @"Select a bitmap to print";
        }
    }else if(indexPath.section == 0){
        
        tableCell.detailTextLabel.text = detailArray[indexPath.row];
    }else {
        
        [[UIDevice currentDevice] model];
        
        NSString *prefix1 = @"Version: ";
        NSString *version = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleShortVersionString"];
        NSString *verionText = [prefix1 stringByAppendingString:version];
        
        NSString *prefix2 = @"  Build: ";
        NSString *release = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleVersion"];
        NSString *releaseText = [prefix2 stringByAppendingString:release];
        
        tableCell.detailTextLabel.text = [verionText stringByAppendingString:releaseText];
    }

    if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
        tableCell.textLabel.textColor = PRTCOLOR_ORANGE;
    }else {
        tableCell.textLabel.textColor = [UIColor grayColor];
    }
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    return tableCell;
}


#pragma mark UITableViewDelegate

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section;
{
    if (section == 0) {
        return @"Fast Test";
    }else if(section == 1){
        return @"Function";
    }else {
        return @"ABOUT";
    }
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    
    return [[MIDScreenFit share] getRowHeight]*0.7;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    
    return 1;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [[MIDScreenFit share] getRowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];//取消选中 cell
    
    HPRTTestPrint *test = [[HPRTTestPrint alloc] init];
    
    if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
    
        switch (indexPath.section) {
            case 0:
                switch (indexPath.row) {
                    case 0: [test testPrintText];       break;
                    case 1: [test testPrintReceipt];    break;
                    case 2: [test testPrintBarcode];    break;
                    default:                        break;
                }
                [self popAlertViewWithTitle:@"Send Success" Message:@"Data send success"];
                break;
            case 1:
                switch (indexPath.row) {
                    case 0: [self popBitmapView];   break;
                    case 1: [self popBarcodeVC];    break;
                    case 2: [self popTextVC];       break;
                    case 3: [self popPageVC];       break;
                    case 4: [self popPhotoVC];      break;
                    default:                        break;
                }
                break;
            case 2:
                [self popAlertViewWithTitle:@"About" Message:@"Email:ios@prttech.com"];
                break;
            default:
                break;
        }
    }
}

@end
