//
//  HPRTBarcodeVC.m
//
//  Created by midmirror on 15/12/25.
//  Copyright © 2015年 midmirror. All rights reserved.
//

#import "HPRTBarcodeVC.h"
#import "HPRTFunctionESC.h"
#import "Masonry.h"

@interface HPRTBarcodeVC ()

@property(strong,nonatomic,readwrite) NSDictionary *tableRowDic;
@end

@implementation HPRTBarcodeVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    UILabel *titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 200, 44)];
    titleLabel.backgroundColor = [UIColor clearColor];
    titleLabel.font = [UIFont systemFontOfSize:20];
    titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    titleLabel.textAlignment = NSTextAlignmentCenter;
    titleLabel.text = @"QRCode/BarCode";
    self.navigationItem.titleView = titleLabel;
    
    [self setupDataSrouce];
    [self setupFlatUI];
    [self setupFootTable];
    
}

- (void)viewWillAppear:(BOOL)animated {
    
     [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationUserSelectCell:) name:@"NotificationUserSelectCell" object:nil];
}

- (void)notificationUserSelectCell:(NSNotification *)sender {
    
    _tableRowDic = [sender userInfo];
    int row = [[_tableRowDic objectForKey:@"row"] intValue];
    [self popPickerViewAt:row];
}

- (void)setupFlatUI {
    
    self.navigationController.navigationBar.barTintColor = PRTCOLOR_BLUE;
    [self.navigationController.navigationBar setTranslucent:NO];
    
    UIColor *headColor = PRTCOLOR_BLUE;
    UIColor *footColor = PRTCOLOR_COULD;
    
    _flatView = [[MIDFlatView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.4 headColor:headColor footColor:footColor];
    _flatView.frame = CGRectMake(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT);
    [self.view addSubview:_flatView];
    
    _inputTF = [[UITextField alloc] init];
    _inputTF.borderStyle = UITextBorderStyleRoundedRect;
    _inputTF.placeholder = @"QRCode/BarCode";
    _inputTF.text = @"075678164125";
    [_flatView.headView addSubview:_inputTF];
    
    [_inputTF mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(self.view.mas_centerX);
        make.top.equalTo(self.view.mas_top).offset(SCREEN_HEIGHT*0.04);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH * 0.8, SCREEN_WIDTH * 0.1));
    }];
    
    _flatView.mainButton.hidden = NO;
    [_flatView.mainButton setTitle:@"Send To Print" forState:UIControlStateNormal];
    [_flatView.mainButton addTarget:self action:@selector(printAction) forControlEvents:UIControlEventTouchUpInside];
    
    MIDScreenFit *fit = [[MIDScreenFit alloc] init];
    CGFloat buttonWidth = [fit getMainButtonWidth];
    CGFloat buttonHeight = [fit getMainButtonHeight];
    
    [_flatView.mainButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(self.view);
        make.bottom.equalTo(_flatView.headView.mas_bottom).offset(-SCREEN_HEIGHT*0.04);
        make.size.mas_equalTo(CGSizeMake(buttonWidth, buttonHeight));
    }];
}

- (void)setupDataSrouce {
    
    NSArray *barcodeTypeArray = @[@"UPC-A",@"UPC-E",@"EAN8",@"EAN13",@"CODE39",@"ITF",@"CODEBAR",@"CODE128",@"CODE93",@"QRCODE"];
    NSArray *alignArray = @[@"Left",@"Center",@"right"];
    NSArray *numberAroundArray = @[@"None",@"print up",@"print down",@"up and down"];
    _detailListArray = @[@[barcodeTypeArray],@[alignArray],@[numberAroundArray],@6,@80];
    
    _codeNumWithTypeDic = @{@"UPC-A":@"075678164125",@"UPC-E":@"01227000009",@"EAN8":@"04210009",@"EAN13":@"6901028075831",@"CODE39":@"123456789",@"ITF":@"123456789012",@"CODEBAR":@"AA12584A",@"CODE128":@"A1256",@"CODE93":@"TEST93",@"QRCODE":@"123456789"};
    
    _detailTextArray = [[NSMutableArray alloc] initWithObjects:@"UPC-A",@"Left",@"None",@"2",@"80", nil];
    _parameterArray = [[NSMutableArray alloc] initWithObjects:@0,@0,@0,@2,@80, nil];
}


- (void)popPickerViewAt:(int)row {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *buttonColor = PRTCOLOR_GRAY;
    
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor buttonColor:buttonColor];
    _popView.titleLabel.text = @"Please Select";
    __block MIDPopView *popView = _popView;
    __block HPRTBarcodeVC *barcodeVC = self;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];        // 隐藏弹出视图
        [barcodeVC updateTitleAndParameter:[NSNumber numberWithInt:row]];   // 更新 FootView 上表视图的副标题，和打印参数
        [barcodeVC setupFootTable];    // 更新 footView 上的表视图
    }];
    
    [_popView show];
    
    NSArray *dataArray;
    if (row < 3 ) {
        
        dataArray = _detailListArray[row];
    }else {
        
        MIDToolBox *tool = [[MIDToolBox alloc] init];
        dataArray = [tool generateNumberArrayWith:_detailListArray[row]];
    }
    
    MIDPickerKit *picker = [[MIDPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:dataArray];
    [_popView.footView addSubview:picker];
}

- (void)updateTitleAndParameter:(NSNumber *)row {
    
    if (row) {
        
        int rowInt = [row intValue];
        MIDToolBox *tool = [[MIDToolBox alloc] init];
        NSString *newDetailTitle = [tool pieceStringWithArray:[MIDPickerKitModel share].titleArray];
        if (rowInt > 2) {
            newDetailTitle = [NSString stringWithFormat:@"%d",[newDetailTitle intValue]];
            [_parameterArray replaceObjectAtIndex:rowInt withObject:newDetailTitle];
            
        }else {
            NSString *pickerRow = [[MIDPickerKitModel share].rowArray[0] stringValue];
            
            if (rowInt == 0) {
                _inputTF.text = [_codeNumWithTypeDic objectForKey:newDetailTitle];
            }
           [_parameterArray replaceObjectAtIndex:rowInt withObject:pickerRow];
        }
        [_detailTextArray replaceObjectAtIndex:[row integerValue] withObject:newDetailTitle];
    }
}

- (void)setupFootTable {
    
    NSArray *titleArray = @[@"BarcodeType",@"Alignment",@"Text Position",@"Width",@"Height"];
    NSArray *tableDataArray = @[titleArray,_detailTextArray];
    
    _tableKit = [[MIDTableKit alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT*0.6 DataArray:tableDataArray TableMode:MIDTableModeNormal CheckMark:NO];
    
    [_flatView.footView addSubview:_tableKit];
}

- (void)printAction
{
    NSString *text = _inputTF.text;
    
    int barcodeType         = [_parameterArray[0] intValue];
    int barcodeAligment     = [_parameterArray[1] intValue];
    int barcodeNumberAround = [_parameterArray[2] intValue];
    int barcodeWidth        = [_parameterArray[3] intValue];
    int barcodeHeight       = [_parameterArray[4] intValue];
    
    HPRTFunctionESC *cmdESC = [[HPRTFunctionESC alloc] init];
    
    if (barcodeType == 9) {
        
//        [[HPRTPrinterESC share] printbarcode2WithAlign:barcodeAligment leftMargin:0 model:50 size:16 errLevel:48 pData:text];
        
        
        NSData *qrcodeData = [cmdESC escPrintQRCodeWithJustification:barcodeAligment LeftMargin:0 Model:50 Size:16 CorrectionLevel:48 QRCode:text];
        [[HPRTDispatcher share] sendData:qrcodeData];
    }else {
        
        NSData *printData = [cmdESC escPrintBarCodeWithJustification:barcodeAligment Type:barcodeType Width:barcodeWidth Height:barcodeHeight HRIPosition:barcodeNumberAround Barcode:text];
        [[HPRTDispatcher share] sendData:printData];
    }
    
    [self popSuccessView];
}

- (void)popSuccessView {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.3 splitPercentage:0.3 headColor:headColor buttonColor:nil];
    _popView.titleLabel.text = @"Send Success";
    _popView.footView.backgroundColor = PRTCOLOR_COULD;
    
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH*0.6, SCREEN_HEIGHT*0.15)];
    label.text = @"Data send success";
    label.textColor = [UIColor grayColor];
    label.textAlignment = NSTextAlignmentCenter;
    label.backgroundColor = PRTCOLOR_COULD;
    [_popView.footView addSubview:label];
    
    __block MIDPopView *popView = _popView;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
    }];
    
    [_popView show];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)viewWillDisappear:(BOOL)animated {
    
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

@end
