//
//  HPRTConnectVC.m
//  HPRTPrinter
//
//  Created by midmirror on 16/2/24.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import "HPRTConnectVC.h"
#import <SystemConfiguration/CaptiveNetwork.h>
#import "Masonry.h"

@interface HPRTConnectVC ()

@property(strong,nonatomic,readwrite) UIImageView *phoneLogoView;
@property(strong,nonatomic,readwrite) UITableView *tableView;
@property(strong,nonatomic,readwrite) UIView *headView;
@property(strong,nonatomic,readwrite) MIDPopView *popView;
@property(strong,nonatomic,readwrite) NSMutableArray *rssiArray;
@property(strong,nonatomic,readwrite) NSMutableArray *distanceArray;
@property(strong,nonatomic,readwrite) NSMutableArray *peripheralArray;
@property(strong,nonatomic,readwrite) NSString *routerName;
@property(strong,nonatomic,readwrite) NSString *routerIP;
@property(strong,nonatomic,readwrite) NSArray *nearbyPeripheralArray;
@property(strong,nonatomic,readwrite) NSIndexPath *indexPathSelected;

@property(strong,nonatomic,readwrite) NSMutableDictionary *peripheralDict;

@end

@implementation HPRTConnectVC

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [[HPRTDispatcher share] scanBluetooth];
    [self getCurrentWifiInfo];
    
    self.edgesForExtendedLayout = UIRectEdgeNone;
    self.view.backgroundColor = PRTCOLOR_COULD;
    
    _tableView = [[UITableView alloc] initWithFrame:CGRectMake(0, SCREEN_HEIGHT*0.3, SCREEN_WIDTH, SCREEN_HEIGHT*0.6) style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    
    [[HPRTDispatcher share] setBLEDelegate:self];
    [[HPRTDispatcher share] setWiFiDelegate:self];
    
    [self.view addSubview:_tableView];
    
    _headView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT*0.3)];
    _headView.backgroundColor = PRTCOLOR_GRAY;
    [self.view addSubview:_headView];
    
    UIView *footView = [[UIView alloc] initWithFrame:CGRectMake(0, SCREEN_HEIGHT*0.9, SCREEN_WIDTH, SCREEN_HEIGHT*0.1)];
    [self.view addSubview:footView];
    
    CGFloat buttonHeight = [[MIDScreenFit share] getMainButtonHeight];
    
    UIButton *closeButton = [[UIButton alloc] init];
    [closeButton addTarget:self action:@selector(closeView) forControlEvents:UIControlEventTouchUpInside];
    closeButton.layer.cornerRadius = buttonHeight/2;
    closeButton.backgroundColor = PRTCOLOR_GRAY;
    closeButton.titleLabel.font = [UIFont systemFontOfSize:[[MIDScreenFit share] getFontSize]];
    [closeButton setTitle:@"Close" forState:UIControlStateNormal];
    [footView addSubview:closeButton];
    
    [closeButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(footView);
        make.centerY.equalTo(footView);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH/2, buttonHeight));
    }];
    
    _rssiArray = [[NSMutableArray alloc] init];
    _distanceArray = [[NSMutableArray alloc] init];
    _peripheralDict = [[NSMutableDictionary alloc] init];
}

- (void)viewWillAppear:(BOOL)animated {
    
     _phoneLogoView = [[UIImageView alloc] init];
    _phoneLogoView.image = [UIImage imageNamed:@"iphone"];
    [_headView addSubview:_phoneLogoView];
    
    [_phoneLogoView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(_headView);
        make.centerY.equalTo(_headView);
        make.size.mas_equalTo(CGSizeMake(30, 60));
    }];
   
    /**
     *  使用定时器开启脉冲动画
     */
    NSTimer *timer = [NSTimer timerWithTimeInterval:0.6 target:self selector:@selector(startAnimation) userInfo:nil repeats:YES];
    [[NSRunLoop mainRunLoop] addTimer:timer forMode:NSRunLoopCommonModes];
}

- (void)startAnimation {
    
    MIDEffectLayer *effect = [[MIDEffectLayer alloc] init];
    CALayer *pulseLayer = [effect generatePulseLayer:_headView];
    [_headView.layer insertSublayer:pulseLayer below:_phoneLogoView.layer];
    
    [self performSelector:@selector(removeLayer:) withObject:pulseLayer afterDelay:1.5];
}

- (void)removeLayer:(CALayer *)layer
{
    [layer removeFromSuperlayer];
}

- (void)closeView {
    
    [[HPRTDispatcher share] stopScanBluetooth];
    [self dismissViewControllerAnimated:YES completion:^{
        
    }];
}

- (void)viewWillDisappear:(BOOL)animated {
    
   [[NSNotificationCenter defaultCenter] removeObserver:self];
    
    [_headView.layer removeAllAnimations];
}

- (void)popAlertViewWithTitle:(NSString *)title Message:(NSString *)message {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.3 splitPercentage:0.3 headColor:headColor buttonColor:nil];
    _popView.footView.backgroundColor = PRTCOLOR_COULD;
    _popView.titleLabel.text = title;
    
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH*0.6, SCREEN_HEIGHT*0.15)];
    label.textColor = [UIColor grayColor];
    label.textAlignment = NSTextAlignmentCenter;
    [_popView.footView addSubview:label];
    label.text = message;
    
    __block MIDPopView *popView = _popView;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
    }];
    
    [_popView show];
}

- (void)getCurrentWifiInfo {
    
    NSArray *interface = (id)CFBridgingRelease(CNCopySupportedInterfaces());
    id info = nil;
    for (NSString *name in interface) {
        info = (id)CFBridgingRelease(CNCopyCurrentNetworkInfo((CFStringRef)name));
    }
    
    _routerName = [info objectForKey:@"SSID"];
    if (_routerName) {
        NSDictionary *routerInfo = [[HPRTDispatcher share] getRouterInfo];
        _routerIP = [routerInfo objectForKey:@"routerIP"];
        
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return 3;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    if (section < 2) {
        return 1;
    }else {
        return _peripheralArray.count;
    }
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"connectCell";
    MIDTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[MIDTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    if (indexPath.section == 0) {
        tableCell.textLabel.textColor = PRTCOLOR_BLUE;
    }
    
    CBPeripheral *p;
    if (_peripheralArray.count > 0) {
        p = _peripheralArray[indexPath.row];
    }
    
    if (indexPath.section == 0) {
        
        if (!_indexPathSelected) {
            
            tableCell.textLabel.text = @"No connection detected";
            tableCell.textLabel.textColor = [UIColor grayColor];
            
        }else {
            
            if (_indexPathSelected.section == 1) {
                
                if (_routerIP) {
                    tableCell.textLabel.text = [NSString stringWithFormat:@"Connecting : %@",_routerName];
                }
                
            }else if (_indexPathSelected.section == 2) {
                
                CBPeripheral *peripheralSelected = _peripheralArray[_indexPathSelected.row];
                tableCell.textLabel.text = [NSString stringWithFormat:@"Connecting : %@",peripheralSelected.name];
            }
        }
        
    }else if (indexPath.section == 1) {
        
        if (_routerName) {
            tableCell.textLabel.text = _routerName;
            tableCell.detailTextLabel.text = _routerIP;
        }else {
            tableCell.textLabel.text = @"WiFi Offline";
            tableCell.textLabel.textColor = [UIColor grayColor];
            tableCell.detailTextLabel.text = @"please connect printer wifi in system setting";
        }
    }else {
        
        
        tableCell.textLabel.text = p.name;
        
        float distance = [_distanceArray[indexPath.row] floatValue];
        tableCell.tagLabelR.text = [[NSString alloc] initWithFormat:@"%@ m",_distanceArray[indexPath.row]];
        
        if (distance < 10) {
            tableCell.tagLabelR.backgroundColor = PRTCOLOR_GREEN;
        }else if (distance >= 10 && distance < 80) {
            tableCell.tagLabelR.backgroundColor = PRTCOLOR_GRAY;
        }else if (distance >= 80) {
            tableCell.tagLabelR.backgroundColor = PRTCOLOR_RED;
            tableCell.tagLabelR.text = @"ERROR";
        }
        
        NSString *timeStatus = [self getTimeStatusWithUUID:[p.identifier UUIDString]];
        tableCell.tagLabelL.text = timeStatus;
        tableCell.tagLabelL.textColor = PRTCOLOR_GRAY;
        
        NSString *detailText = [[NSString alloc] initWithFormat:@"UUID:%@ RSSI:%@",[p.identifier UUIDString],_rssiArray[indexPath.row]];
        tableCell.detailTextLabel.text = detailText;
    }
    
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    
    return tableCell;
}


#pragma mark UITableViewDelegate

//- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section;
//{
//    switch (section) {
//        case 0:     return @"Current";    break;
//        case 1:     return @"WiFi";         break;
//        case 2:     return @"Bluetooth";    break;
//            
//        default:    return @"Unknown";      break;
//    }
//}

- (nullable UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    
    float sectionHeaderHeight = [[MIDScreenFit share] getRowHeight];
    
    UIView *sectionHeadView = [[UIView alloc] init];
    sectionHeadView.frame = CGRectMake(0, 0, SCREEN_WIDTH, sectionHeaderHeight);
    
    UILabel *iconLb = [[UILabel alloc] init];
    iconLb.frame = CGRectMake(15, (sectionHeaderHeight*0.7-20)/2, 50, 20);
    [sectionHeadView addSubview:iconLb];
    
    iconLb.backgroundColor = PRTCOLOR_BLUE;
    iconLb.textAlignment = NSTextAlignmentCenter;
    iconLb.textColor = [UIColor whiteColor];
    iconLb.layer.cornerRadius = 5;
    iconLb.layer.masksToBounds = YES;
    
    if (section == 0) {
        iconLb.text = @"Wired";
        
        if (!_indexPathSelected) {
            iconLb.backgroundColor = PRTCOLOR_GRAY;
        }
    }else if(section == 1){
        
        iconLb.text = @"WiFi";
        if (!_routerName) {
            iconLb.backgroundColor = PRTCOLOR_GRAY;
        }
    }else {
        iconLb.text = @"BLE";
        
        UILabel *noticeLb = [[UILabel alloc] init];
        noticeLb.frame = CGRectMake(70, (sectionHeaderHeight*0.7-20)/2,  200, 20);
        [sectionHeadView addSubview:noticeLb];
        
        noticeLb.backgroundColor = PRTCOLOR_BLUE;
        noticeLb.textAlignment = NSTextAlignmentCenter;
        noticeLb.textColor = [UIColor whiteColor];
        noticeLb.layer.cornerRadius = 5;
        noticeLb.layer.masksToBounds = YES;
        noticeLb.text = @"距离仅作为信号强度参考";
    }
    
    return sectionHeadView;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    
    return [[MIDScreenFit share] getRowHeight]*0.7;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    
    return 1;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [[MIDScreenFit share] getRowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];//取消选中 cell
    _indexPathSelected = indexPath;
    
    [_tableView reloadData];
    
    if (indexPath.section == 1) {
        
        if (_routerIP) {
            [HPRTDispatcher share].wifiConnectedName = _routerName;
            [[HPRTDispatcher share] connectWifi:_routerIP];
        }
        
    }else if (indexPath.section == 2) {
        
        CBPeripheral *p = _peripheralArray[indexPath.row];
        [[HPRTDispatcher share] connectBluetooth:p];
    }
}

#pragma mark HPRTDispatchProtocol

- (void)didDiscoverPeripheral:(CBPeripheral *)peripheral RSSI:(NSNumber *)RSSI {
    
    NSString *uuidKey = [peripheral.identifier UUIDString];
    NSArray *bleArray = @[peripheral,RSSI];
    [_peripheralDict setObject:bleArray forKey:uuidKey];
    
    _peripheralArray = [[NSMutableArray alloc] init];
    
    NSArray *allKeys = [_peripheralDict allKeys];
    for (NSString *key in allKeys) {
        
        NSArray *tmp = [_peripheralDict objectForKey:key];
        [_peripheralArray addObject:tmp[0]];
        [_rssiArray addObject:[tmp[1] stringValue]];
        
        NSString *distance = [[HPRTDispatcher share] generateDistanceWithRSSI:[tmp[1] intValue]];
        [_distanceArray addObject:distance];
    }
    
    [_tableView reloadData];
}

- (void)didConnectPeripheral:(CBPeripheral *)peripheral {
    
    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
    NSDictionary *histroyDevice = [userDefaults objectForKey:@"deviceRecord"];
    
    NSMutableDictionary *deviceRecordDict = [[NSMutableDictionary alloc] initWithDictionary:histroyDevice];
    [deviceRecordDict setObject:[self getCurrentTimeIntervalSince1970] forKey:[peripheral.identifier UUIDString]];
    
    [userDefaults setObject:deviceRecordDict forKey:@"deviceRecord"];
    [userDefaults synchronize];
    
    [self closeView];
}

- (void)didConnectWiFi:(NSString *)ip {
    
    [self closeView];
}

/**
 *  获取自1970年到此刻的时间间隔
 *
 *  @return 时间间隔（单位：秒）
 */
- (NSString *)getCurrentTimeIntervalSince1970
{
    NSDate *nowDate = [NSDate date];
    
    NSTimeInterval time = [nowDate timeIntervalSince1970];
    NSString *timeIntervalSince1970 = [[NSString alloc] initWithFormat:@"%f",time];
    
    return timeIntervalSince1970;
}

/**
 * 根据保存在 UserDefault 中的 deviceReord，用 uuid 取出上一次连接的时间。计算间隔
 *
 *  @param uuidKey 扫描到外设的 uuid
 */
- (NSString *)getTimeStatusWithUUID:(NSString *)uuidKey
{
    NSDictionary *deviceRecordDcit = [[NSUserDefaults standardUserDefaults] objectForKey:@"deviceRecord"];
    
    NSArray *allKeys = [deviceRecordDcit allKeys];
    
    for (NSString *key in allKeys) {
        
        if ([key isEqualToString:uuidKey]) {
            
            double timeInterval = [[deviceRecordDcit objectForKey:uuidKey] doubleValue];
            double currentTime = [[self getCurrentTimeIntervalSince1970] doubleValue];
            double interval =  currentTime - timeInterval;
            
            if (interval <= 60)                                                         return @"刚刚";
            else if ((interval>60) && (interval <= 60 * 10))                            return @"几分钟内";
            else if ((interval>60 * 10) && (interval <= 60 * 30))                       return @"半小时内";
            else if ((interval>60 * 30) && (interval <= 60 * 60))                       return @"1小时内";
            else if ((interval>60 * 60) && (interval <= 60 * 60 *24 ))                  return @"24小时内";
            else if ((interval>60 * 60 * 24) && (interval <= 60 * 60 * 24 * 7))         return @"1周内";
            else if ((interval>60 * 60 * 24 * 7) && (interval <= 60 * 60 * 24 * 30))    return @"1个月内";
            else                                                                        return @"很久以前";
        }
    }
    return nil;
}



@end
