//
//  HPRTHomeTable.m
//  HPRTPrinter
//
//  Created by midmirror on 16/3/7.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import "HPRTHomeTable.h"
#import <MIDKit/MIDKit.h>
#import <HPRTSDK/HPRTSDK.h>

@interface HPRTHomeTable()

@property(strong,nonatomic,readwrite) UITableView *tableView;

@property(strong,nonatomic,readwrite) NSArray *titleArray;
@property(strong,nonatomic,readwrite) NSArray *detailArray;
@property(strong,nonatomic,readwrite) NSArray *iconArray;

@end

@implementation HPRTHomeTable

- (id)initWithDataArray:(NSArray *)dataArray {
    
    if (self = [super init]) {
        
        _titleArray  = dataArray[0];
        _detailArray = dataArray[1];
        _iconArray   = dataArray[2];
        
        self.frame = CGRectMake(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT);
        
        _tableView = [[UITableView alloc] init];
        _tableView.frame = self.frame;
        [self addSubview:_tableView];
        
        _tableView.delegate = self;
        _tableView.dataSource = self;
        
        UIView *v = [[UIView alloc] initWithFrame:CGRectZero];//隐藏多余的 cell
        [_tableView setTableFooterView:v];
    }
    return self;
}

#pragma --mark table
-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return [[MIDScreenFit share] getRowHeight];
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section
{
    return [[MIDScreenFit share] getRowHeight]*0.7;
}

//- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section;

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [_titleArray[section] count];
}

- (nullable UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    
    float sectionHeaderHeight = [[MIDScreenFit share] getRowHeight];
    
    UIView *sectionHeadView = [[UIView alloc] init];
    sectionHeadView.frame = CGRectMake(0, 0, SCREEN_WIDTH, sectionHeaderHeight);
    sectionHeadView.backgroundColor = PRTCOLOR_COULD;
    
    UILabel *iconLb = [[UILabel alloc] init];
    iconLb.frame = CGRectMake(15, (sectionHeaderHeight*0.7-20)/2, 50, 20);
    [sectionHeadView addSubview:iconLb];
    
    if ([HPRTDispatcher share].currentDispatchMode == DispatchModeOffline) {
        
        iconLb.textColor = [UIColor grayColor];
    } else {
        
        iconLb.textColor = [UIColor whiteColor];
        iconLb.layer.cornerRadius = 5;
        iconLb.layer.masksToBounds = YES;
        iconLb.backgroundColor = PRTCOLOR_ORANGE;
    }
    iconLb.textAlignment = NSTextAlignmentCenter;
    
    
    if (section == 0) {
        iconLb.text = @"Test";
        
    }else if(section == 1){
        
        iconLb.text = @"Func";
    }else {
        iconLb.text = @"About";
    }
    
    return sectionHeadView;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *iden = @"cellIden";
    MIDTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[MIDTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    if ([_titleArray[Text] count] != 0) { //防止 cell 崩溃
        
        tableCell.imageView.image = [UIImage imageNamed:_iconArray[indexPath.section][indexPath.row]];
        tableCell.imageView.contentMode = UIViewContentModeScaleAspectFit;
        tableCell.textLabel.text = _titleArray[indexPath.section][indexPath.row];
        
        if ([_detailArray[indexPath.section] count] != 0) {
            
            tableCell.detailTextLabel.text = _detailArray[indexPath.section][indexPath.row];
        }
        
        if (indexPath.section == 1) {
            tableCell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        }else if (indexPath.section == 2){
            
            MIDToolBox *tool = [[MIDToolBox alloc] init];
            NSString *version = [tool getCurrentVersion];
            tableCell.detailTextLabel.text = version;
        }
        
        if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
            tableCell.textLabel.textColor = PRTCOLOR_ORANGE;
        }else {
            tableCell.textLabel.textColor = [UIColor grayColor];
        }
        tableCell.detailTextLabel.textColor = [UIColor grayColor];
        
        if (indexPath.section == 2) {
            tableCell.textLabel.textColor = PRTCOLOR_ORANGE;
        }
    }
    return tableCell;
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];//取消选中 cell
    [[NSNotificationCenter defaultCenter] postNotificationName:@"HPRTNotiClickHomeCell" object:nil userInfo:@{@"indexPath":indexPath}];
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;
{
    return _titleArray.count;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section;
{
    switch (section) {
        case 0: return @"Fast Test";    break;
        case 1: return @"Func";         break;
        case 2: return @"About";        break;
            
        default:    return @"Unknown";  break;
    }
}

@end
