//
//  HPRTHomeVC.m
//
//  Created by midmirror on 16/1/27.
//  Copyright © 2016年 PRT. All rights reserved.
//

#import "HPRTHomeVC.h"
#import "Masonry.h"
#import "HPRTBarcodeVC.h"
#import "HPRTTextVC.h"
#import "HPRTPageVC.h"
#import "HPRTBitmapVC.h"
#import "HPRTConnectVC.h"
#import "HPRTTestESC.h"
#import "HPRTTestTSC.h"
#import "HPRTTscVC.h"
#import "HPRTTscBarcodeVC.h"
#import "HPRTTscTextVC.h"
#import "HPRTHomeTable.h"

@interface HPRTHomeVC ()

@property(strong,nonatomic,readwrite) MIDFlatView *flatView;
@property(strong,nonatomic,readwrite) HPRTHomeTable *homeTableView;
@property(strong,nonatomic,readwrite) NSArray *btnArray;
@property(strong,nonatomic,readwrite) NSDictionary *tableRowDic;
@property(strong,nonatomic,readwrite) UILabel *titleLabel;
@property(strong,nonatomic,readwrite) UILabel *printNameLabel;
@property(strong,nonatomic,readwrite) UILabel *rssiLabel;
@property(assign,nonatomic,readwrite) CGFloat buttonWidth;
@property(assign,nonatomic,readwrite) CGFloat buttonHeight;
@property(strong,nonatomic,readwrite) NSString *currentPrinterName;
@property(assign,nonatomic,readwrite) int instructionIndex;
@property(assign,nonatomic,readwrite) BOOL autoSettingInstruction;

@end

@implementation HPRTHomeVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    _instructionIndex = 0;
    _autoSettingInstruction = YES;
    _tableKit = [MIDTableKit share];
    
    _titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 250, 44)];
    _titleLabel.backgroundColor = [UIColor clearColor];
    _titleLabel.font = [UIFont fontWithName:@"Gurmukhi MN" size:30];
    _titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    _titleLabel.textAlignment = NSTextAlignmentCenter;
    _titleLabel.text = @"HPRT";
    self.navigationItem.titleView = _titleLabel;
    
    self.edgesForExtendedLayout = UIRectEdgeNone;
}

- (void)pushTSCVC {
    
    HPRTTscVC *tsc = [[HPRTTscVC alloc] init];
    [self.navigationController pushViewController:tsc animated:YES];
}

- (void)popAlertViewWithTitle:(NSString *)title Message:(NSString *)message {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.3 splitPercentage:0.3 headColor:headColor buttonColor:nil];
    _popView.footView.backgroundColor = PRTCOLOR_COULD;
    _popView.titleLabel.text = title;
    
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH*0.6, SCREEN_HEIGHT*0.15)];
    label.textColor = [UIColor grayColor];
    label.textAlignment = NSTextAlignmentCenter;
    [_popView.footView addSubview:label];
    label.text = message;
    
    __block MIDPopView *popView = _popView;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
    }];
    
    [_popView show];
}

- (void)popAboutView {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *buttonColor = [UIColor whiteColor];
    
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.8 Height:SCREEN_HEIGHT*0.5 splitPercentage:0.2 headColor:headColor buttonColor:buttonColor];
    
    __block MIDPopView *popView = _popView;
    
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
        
    }];
    
    [_popView show];
    
    _popView.titleLabel.text = @"About";
    NSString *copyright = @"Copyright 2016 Xiamen Hanin. All rights reserved";
    
    MIDToolBox *tool = [[MIDToolBox alloc] init];
    NSString *version = [tool getCurrentVersion];
    NSArray *dataArray = @[@[@"Version",@"Contact",@"Copyright"],@[version,@"ios@prttech.com",copyright]];
    
    MIDTableKit *tableKit = [[MIDTableKit alloc] initWithWidth:SCREEN_WIDTH*0.8 Height:SCREEN_HEIGHT*0.4 DataArray:dataArray TableMode:MIDTableModeTextAdaptive CheckMark:NO];
    [_popView.footView addSubview:tableKit];
}

- (void)viewWillAppear:(BOOL)animated {
    
    [self startShimmering];
    [self setMainView];
    
    self.navigationController.navigationBar.translucent = NO;
    
    //隐藏导航栏下面的线条
    [self.navigationController.navigationBar setBackgroundImage:[[UIImage alloc] init] forBarMetrics:UIBarMetricsDefault];
    self.navigationController.navigationBar.shadowImage = [[UIImage alloc] init];
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(clickHomeCellAction:) name:@"HPRTNotiClickHomeCell" object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationUserSelectCell:) name:@"NotificationUserSelectCell" object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(startShimmering) name:UIApplicationDidBecomeActiveNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationUpdateRSSI:) name:@"HPRTBluetoothUpdateRSSI" object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(setMainView) name:@"HPRTDispatchModeChangeToOffline" object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(setMainView) name:@"HPRTDispatchModeChangeToBLE" object:nil];
}

- (void)notificationUpdateRSSI:(NSNotification *)sender {
    
    int rssi = [[[sender userInfo] objectForKey:@"RSSI"] intValue];
    NSString *distance = [[HPRTDispatcher share] generateDistanceWithRSSI:rssi];
    
    _rssiLabel.text = [[NSString alloc] initWithFormat:@"%@ m",distance];
    
    float tmpDistance = [distance floatValue];
    if (tmpDistance < 10) {
        _rssiLabel.backgroundColor = PRTCOLOR_GREEN;
    }else if (tmpDistance >= 10 && tmpDistance < 80) {
        _rssiLabel.backgroundColor = PRTCOLOR_GRAY;
    }else if (tmpDistance >= 80) {
        _rssiLabel.backgroundColor = PRTCOLOR_RED;
        _rssiLabel.text = @"ERROR";
    }
}


- (void)startShimmering {
    
    MIDEffectLayer *effect = [[MIDEffectLayer alloc] init];
    CAGradientLayer *shimmerLayer = [effect generateShimmerLayer];
    shimmerLayer.frame = _titleLabel.frame;
    _titleLabel.layer.mask = shimmerLayer;
}

- (void)viewWillDisappear:(BOOL)animated {
    
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)notificationUserSelectCell:(NSNotification *)sender {
    
    _tableRowDic = [sender userInfo];
}

#pragma mark Setup View
- (void)setMainView {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *footColor = [UIColor whiteColor];
    _flatView = [[MIDFlatView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.35 headColor:headColor footColor:footColor];
    [self.view addSubview:_flatView];
    
    _buttonWidth = [[MIDScreenFit share] getMainButtonWidth];
    _buttonHeight = [[MIDScreenFit share] getMainButtonHeight];
    
    _bluetoothButton = [[UIButton alloc] init];
    [_bluetoothButton addTarget:self action:@selector(popConnectVC) forControlEvents:UIControlEventTouchUpInside];
    _bluetoothButton.layer.borderWidth = 0.5;
    _bluetoothButton.layer.cornerRadius = _buttonHeight/2;
    _bluetoothButton.layer.borderColor = [UIColor whiteColor].CGColor;
    _bluetoothButton.titleLabel.font = [UIFont systemFontOfSize:[[MIDScreenFit share] getFontSize]];
    
    [self setCycleView];
    [self setChangeView];
}

- (void)popConnectVC {
    
    if ([HPRTDispatcher share].currentDispatchMode == DispatchModeOffline) {

        HPRTConnectVC *connectVC = [[HPRTConnectVC alloc] init];
        [self presentViewController:connectVC animated:YES completion:^{
            
        }];
        
    }else {
        
        [[HPRTDispatcher share] disConnectCurrentLine];
    }
}

//根据设备型号决定是否展示那个半圆。
- (void)setCycleView {
    
    if (SCREEN_RESOLUTION > iphone5) { //尺寸大于 iPhone5才展示
        
        MIDDrawView *cycleView = [[MIDDrawView alloc] init];
        
        [_flatView.headView addSubview:cycleView];
        
        CGFloat diameter = [[MIDScreenFit share] getDiameter];
        
        [cycleView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.equalTo(_flatView.headView.mas_centerX);
            make.top.equalTo(_flatView.headView.mas_top);
            make.size.mas_equalTo(CGSizeMake(diameter, diameter/2));
        }];
        
        [_flatView.headView addSubview:_bluetoothButton];
        [_bluetoothButton mas_makeConstraints:^(MASConstraintMaker *make) {
            
            make.centerX.equalTo(_flatView.headView);
            make.centerY.equalTo(cycleView.mas_bottom);
            make.size.mas_equalTo(CGSizeMake(_buttonWidth, _buttonHeight));
        }];
        
    }else {
        
        [_flatView.headView addSubview:_bluetoothButton];
        
        [_bluetoothButton mas_makeConstraints:^(MASConstraintMaker *make) {
            
            make.centerX.equalTo(_flatView.headView);
            make.centerY.equalTo(_flatView.headView);
            make.size.mas_equalTo(CGSizeMake(_buttonWidth, _buttonHeight));
        }];
    }
}

// 判断是否连接打印机，改变视图展示信息
- (void)setChangeView {
    
    UIColor *headColor;
    
    [_bluetoothButton setTitle:@"Connect Printer" forState:UIControlStateNormal];
    
    NSLog(@"dispatchMode:%ld",(long)[HPRTDispatcher share].currentDispatchMode);
        
    _printNameLabel = [[UILabel alloc] init];
    [_flatView.headView addSubview:_printNameLabel];
    _printNameLabel.textColor = [UIColor whiteColor];
    _printNameLabel.textAlignment = NSTextAlignmentCenter;
    _printNameLabel.font = [UIFont systemFontOfSize:[[MIDScreenFit share] getFontSize]-5];
    _printNameLabel.numberOfLines = 0;
    [_printNameLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(_flatView.headView);
        make.bottom.equalTo(_bluetoothButton.mas_top).offset(-10);
        make.size.mas_equalTo(CGSizeMake(_buttonWidth, _buttonHeight/2));
    }];
    
    _rssiLabel = [[UILabel alloc] init];
    [_flatView.headView addSubview:_rssiLabel];
    _rssiLabel.textColor = [UIColor whiteColor];
    _rssiLabel.textAlignment = NSTextAlignmentCenter;
    _rssiLabel.layer.cornerRadius = 5;
    _rssiLabel.layer.masksToBounds = YES;
    _rssiLabel.font = [UIFont systemFontOfSize:[[MIDScreenFit share] getFontSize]-5];
    _rssiLabel.numberOfLines = 0;
    [_rssiLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(_flatView.headView);
        make.bottom.equalTo(_printNameLabel.mas_top);
        make.size.mas_equalTo(CGSizeMake(60, 20));
    }];
    
    if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
        
        UIButton *tscBtn = [UIButton buttonWithType:UIButtonTypeCustom];
        [tscBtn setImage:[UIImage imageNamed:@"circulate"] forState:UIControlStateNormal];
        tscBtn.frame = CGRectMake(0, 0, 40, 40);
        tscBtn.titleLabel.textAlignment = NSTextAlignmentRight;
        [tscBtn addTarget:self action:@selector(setupInstruction) forControlEvents:UIControlEventTouchUpInside];
        UIBarButtonItem *rightItem = [[UIBarButtonItem alloc] initWithCustomView:tscBtn];
        self.navigationItem.rightBarButtonItem = rightItem;
    }
    
    switch ([HPRTDispatcher share].currentDispatchMode) {
            
        case DispatchModeOffline:
            
            headColor = PRTCOLOR_GRAY;
            break;
        case DispatchModeBLE:
            
            headColor = PRTCOLOR_ORANGE;
            [_bluetoothButton setTitle:@"Disconnect BLE" forState:UIControlStateNormal];
            _currentPrinterName = [HPRTDispatcher share].bleConnected.name;
            [self setupInstructionModeByPrinterName:_currentPrinterName];
            break;
            
        case DispatchModeWIFI:
            
            headColor = PRTCOLOR_ORANGE;
            [_bluetoothButton setTitle:@"Disconnect Wifi" forState:UIControlStateNormal];
            _currentPrinterName = [HPRTDispatcher share].wifiConnectedName;
            [self setupInstructionModeByPrinterName:_currentPrinterName];
            break;
            
        default:
            break;
    }
    
    self.navigationController.navigationBar.barTintColor = headColor;
    _flatView.headView.backgroundColor = headColor;
    
    [self setFootTableView];
}

- (void)setFootTableView {
    
    NSString *appName = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleName"];
    NSArray *titleArray,*detailArray,*iconArray;
    InstructionMode intructionMode = [HPRTDispatcher share].currentInstructionMode;
    
    if (intructionMode == InstructionModeESC_POS) {
        titleArray = @[@[@"Phrase",@"Receipt",@"Barcode"],@[@"Barcode",@"Text",@"Page",@"Bitmap"],@[appName]];
        detailArray = @[@[@"Direct print text with format",@"Direct print a receipt",@"Direct print some barcode"],@[],@[]];
        iconArray = @[@[@"phrase",@"receipt",@"barcode"],@[@"barcode",@"text",@"page",@"bitmap"],@[@"printer"]];
    }else {
        titleArray = @[@[@"SelfTest",@"Receipt",@"Barcode",@"Label"],@[@"Barcode",@"Text",@"Bitmap"],@[appName]];
        detailArray = @[@[@"Direct print Printer Selftest",@"Direct print a receipt",@"Direct print some barcode",@"Direct print a label"],@[],@[]];
        iconArray = @[@[@"phrase",@"receipt",@"barcode",@"barcode"],@[@"barcode",@"text",@"page",@"bitmap"],@[@"printer"]];
    }
    
    _homeTableView = [[HPRTHomeTable alloc] initWithDataArray:@[titleArray,detailArray,iconArray]];
    
    float cellHeight = [[MIDScreenFit share] getRowHeight];
    float scrollHeight = 8 * cellHeight + 3 * cellHeight *0.7;
    
    UIScrollView *scrollView = [[UIScrollView alloc] initWithFrame:self.view.bounds];
    scrollView.scrollEnabled = YES;
    scrollView.contentSize = CGSizeMake(_flatView.footView.bounds.size.width, scrollHeight*1.4);
    [_flatView.footView addSubview:scrollView];
    [scrollView addSubview:_homeTableView];
}

/**
 *  设定指令集，并改变显示标签
 *
 *  @param name 打印机型号
 */
- (void)setupInstructionModeByPrinterName:(NSString *)name {
    
    if (_autoSettingInstruction) {  //如果是默认自动设置指令集。
        
        if (![[HPRTDispatcher share] isEscPosInstruction:name]) {
            if ([[HPRTDispatcher share] isTscTsplInstrution:name]) {
                
                [HPRTDispatcher share].currentInstructionMode = InstructionModeTSC_TSPL;
            }
        }else {
            
            [HPRTDispatcher share].currentInstructionMode = InstructionModeESC_POS;
        }
    }
    
    [self switchPrinterNameLabelText];
}

//根据当前指令集并改变显示标签
- (void)switchPrinterNameLabelText {
    
    switch ([HPRTDispatcher share].currentInstructionMode) {
            
        case InstructionModeESC_POS:
           _printNameLabel.text = [NSString stringWithFormat:@"%@ (ESC-POS)",_currentPrinterName];
            break;
        case InstructionModeTSC_TSPL:
            _printNameLabel.text = [NSString stringWithFormat:@"%@ (TSC-TSPL)",_currentPrinterName];
            break;
            
        default:
            break;
    }
}

//手动切换指令集
- (void)setupInstruction {
    
    if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {    //当前连接打印机时
        _autoSettingInstruction = NO;   //当手动设置指令集时，关闭自动设置指令集
        
        if (_instructionIndex > 1) {
            _instructionIndex = _instructionIndex%2;
        }
        
        switch (_instructionIndex++) {
            case InstructionModeESC_POS:
                [HPRTDispatcher share].currentInstructionMode = InstructionModeESC_POS;
                break;
            case InstructionModeTSC_TSPL:
                [HPRTDispatcher share].currentInstructionMode = InstructionModeTSC_TSPL;
                break;
                
            default:
                break;
        }
        
        [self switchPrinterNameLabelText];
        [self setFootTableView];
    }
}


- (void)empty {
    
    _tableRowDic = nil;
}

#pragma mark Func

- (void)popTextVC {
    
    HPRTTextVC *textVC = [[HPRTTextVC alloc] init];
    [self.navigationController pushViewController:textVC animated:YES];
}

- (void)popBarcodeVC {
    
    HPRTBarcodeVC *barcodeVC = [[HPRTBarcodeVC alloc] init];
    [self.navigationController pushViewController:barcodeVC animated:YES];
}

- (void)popPageVC {
    
    HPRTPageVC *pageVC = [[HPRTPageVC alloc] init];
    [self.navigationController pushViewController:pageVC animated:YES];
}

- (void)popBitmapVC {
    
    HPRTBitmapVC *bitmapVC = [[HPRTBitmapVC alloc] init];
    [self.navigationController pushViewController:bitmapVC animated:YES];
}

- (void)didReceiveMemoryWarning {
    
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)clickHomeCellAction:(NSNotification *)sender {
    
    NSIndexPath *indexPath = [[sender userInfo] objectForKey:@"indexPath"];
    
    switch ([HPRTDispatcher share].currentInstructionMode) {
        case InstructionModeESC_POS:    [self escPosFunctionSwitcher:indexPath];   break;
        case InstructionModeTSC_TSPL:   [self tscTsplFunctionSwitcher:indexPath];  break;
            
        default:        break;
    }
    
    if (indexPath.section == 2) {
        [self popAboutView];
    }
}

- (void)escPosFunctionSwitcher:(NSIndexPath *)indexPath {
    
    HPRTTestESC *testESC = [[HPRTTestESC alloc] init];
    
    switch (indexPath.section) {
        case 0:
            if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
                switch (indexPath.row) {
                    case 0: [testESC printText];       break;
                    case 1: [testESC printReceipt];    break;
                    case 2: [testESC printBarcode];    break;
                    default:                           break;
                }
                [self popAlertViewWithTitle:@"Send Success" Message:@"Data send success"];
            }
    
            break;
        case 1:
            
            if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
                switch (indexPath.row) {
                    case 0: [self popBarcodeVC];    break;
                    case 1: [self popTextVC];       break;
                    case 2: [self popPageVC];       break;
                    case 3: [self popBitmapVC];     break;
                    default:                        break;
                }
            }
    
            break;
        default:
            break;
    }
}

- (void)tscTsplFunctionSwitcher:(NSIndexPath *)indexPath {
    
    HPRTTestTSC *testTSC = [[HPRTTestTSC alloc] init];
    
    switch (indexPath.section) {
        case 0:
            if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
                switch (indexPath.row) {
                    case 0: [testTSC selfTest];        break;
                    case 1: [testTSC printReceipt];    break;
                    case 2: [testTSC printBarcode];    break;
                    case 3: [testTSC printLabel];      break;
                    default:                           break;
                }
                [self popAlertViewWithTitle:@"Send Success" Message:@"Data send success"];
            }
            
            break;
        case 1:
            
            if ([HPRTDispatcher share].currentDispatchMode != DispatchModeOffline) {
                switch (indexPath.row) {
                    case 0: [self pushTscBarcodeVC];    break;
                    case 1: [self pushTscTextVC];       break;
                    case 2: [self popBitmapVC];         break;
                    default:                            break;
                }
            }
    
            break;
        default:
            break;
    }
}

- (void)pushTscBarcodeVC {
    
    HPRTTscBarcodeVC *tscBarcodeVC = [[HPRTTscBarcodeVC alloc] init];
    [self.navigationController pushViewController:tscBarcodeVC animated:YES];
}

- (void)pushTscTextVC {
    
    HPRTTscTextVC *tscTextVC = [[HPRTTscTextVC alloc] init];
    [self.navigationController pushViewController:tscTextVC animated:YES];
}

@end
