//
//  HPRTTextVC.m
//  BluetoothPrinter
//
//  Created by midmirror on 15/12/28.
//  Copyright © 2015年 midmirror. All rights reserved.
//

#import "HPRTTextVC.h"
#import "HPRTFunctionESC.h"
#import "Masonry.h"

@interface HPRTTextVC ()

@property(strong,nonatomic,readwrite) NSDictionary *tableRowDic;
@end

@implementation HPRTTextVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    UILabel *titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 200, 44)];
    titleLabel.backgroundColor = [UIColor clearColor];
    titleLabel.font = [UIFont systemFontOfSize:20];
    titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    titleLabel.textAlignment = NSTextAlignmentCenter;
    titleLabel.text = @"Text Print";
    self.navigationItem.titleView = titleLabel;
    
    [self setupDataSource];
    [self setupFlatView];
    [self setupFootTable];
    
    _tableKit = [MIDTableKit share];
    
}

- (void)notificationUserSelectCell:(NSNotification *)sender {
    
    _tableRowDic = [sender userInfo];
    int row = [[_tableRowDic objectForKey:@"row"] intValue];
    
    if (row >= 6) {
        
        [self popPickerViewAt:row];
    }else {
        
        [self updateTitleAndParameter:[NSNumber numberWithInt:row]];
        [self setupFootTable];
    }
}

- (void)viewWillAppear:(BOOL)animated {
    
    self.navigationController.navigationBar.barTintColor = PRTCOLOR_BLUE;
    [self.navigationController.navigationBar setTranslucent:NO];
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationUserSelectCell:) name:@"NotificationUserSelectCell" object:nil];
}

- (void)viewWillDisappear:(BOOL)animated {
    
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)setupDataSource {
    
    _detailTextArray = [[NSMutableArray alloc] initWithObjects:@"NO",@"NO",@"NO",@"NO",@"NO",@"NO",@"0",@"0",@"0",@"Left", nil];
    _parameterArray = [[NSMutableArray alloc] initWithObjects:@"NO",@"NO",@"NO",@"NO",@"NO",@"NO",@"0",@"0",@"0",@"0", nil];
}

- (void)setupFlatView {
    
    UIColor *headColor = PRTCOLOR_BLUE;
    UIColor *footColor = PRTCOLOR_COULD;
    
    _flatView = [[MIDFlatView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.4 headColor:headColor footColor:footColor];
    [self.view addSubview:_flatView];
    
    [_flatView.textView setText:@"Xiamen Hanin Electronic Technology Co., Ltd."];
    
    [_flatView.textView mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view.mas_centerX);
        make.top.equalTo(self.view.mas_top).offset(SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH * 0.8, SCREEN_WIDTH * 0.15));
    }];
    
    _flatView.mainButton.hidden = NO;
    [_flatView.mainButton setTitle:@"Send To Print" forState:UIControlStateNormal];
    [_flatView.mainButton addTarget:self action:@selector(sendToPrinterAction) forControlEvents:UIControlEventTouchUpInside];
    
    MIDScreenFit *fit = [[MIDScreenFit alloc] init];
    CGFloat buttonWidth = [fit getMainButtonWidth];
    CGFloat buttonHeight = [fit getMainButtonHeight];
    
    [_flatView.mainButton mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view);
        make.bottom.equalTo(_flatView.headView.mas_bottom).offset(-SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(buttonWidth, buttonHeight));
    }];
}

- (void)updateTitleAndParameter:(NSNumber *)row {
    
    if (row) {
        
        int rowInt = [row intValue];
        if ([row intValue] > 5) {
            
            MIDToolBox *tool = [[MIDToolBox alloc] init];
            NSString *newDetailTitle = [tool pieceStringWithArray:[MIDPickerKitModel share].titleArray];
            
            if ([row intValue] != 9) {
                newDetailTitle = [NSString stringWithFormat:@"%d",[newDetailTitle intValue]];
                [_parameterArray replaceObjectAtIndex:rowInt withObject:newDetailTitle];
            }else {
                NSString *pickerRow = [[MIDPickerKitModel share].rowArray[0] stringValue];
                [_parameterArray replaceObjectAtIndex:rowInt withObject:pickerRow];
            }
            [_detailTextArray replaceObjectAtIndex:rowInt withObject:newDetailTitle];
            
        }else {
            
            if ([_detailTextArray[rowInt] isEqualToString:@"YES"]) {
                
                [_detailTextArray replaceObjectAtIndex:rowInt withObject:@"NO"];
                [_parameterArray replaceObjectAtIndex:rowInt withObject:@"NO"];
            }else {
                
                [_detailTextArray replaceObjectAtIndex:rowInt withObject:@"YES"];
                [_parameterArray replaceObjectAtIndex:rowInt withObject:@"YES"];
            }
        }
    }
}

- (void)setupFootTable {
    
    NSArray *titleArray = @[@"DHeight",@"DWidth",@"ULine",@"Bold",@"Mini",@"Reverse",@"DHeight",@"DWidth",@"LMargin",@"Align"];
    
    NSArray *tableDataArray = @[titleArray,_detailTextArray];
    
    _tableKit = [[MIDTableKit alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT*0.6 DataArray:tableDataArray TableMode:MIDTableModeNormal CheckMark:NO];
    
    [_flatView.footView addSubview:_tableKit];
}

- (void)popPickerViewAt:(int)row {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *buttonColor = PRTCOLOR_COULD;
    
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor buttonColor:buttonColor];
    _popView.titleLabel.text = @"Please Select";
    
    __block MIDPopView *popView = _popView;
    __block HPRTTextVC *textVC = self;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
        [textVC updateTitleAndParameter:[NSNumber numberWithInt:row]];
        [textVC setupFootTable];
    }];
    
    [_popView show];
    
    MIDToolBox *tool = [[MIDToolBox alloc] init];
    NSArray *dataArray;
    
    switch (row) {
            
        case 6: dataArray = [tool generateNumberArrayWith:@8];      break;
        case 7: dataArray = [tool generateNumberArrayWith:@8];      break;
        case 8: dataArray = [tool generateNumberArrayWith:@100];    break;
        case 9: dataArray = @[@[@"Left",@"Center",@"Right"]];       break;
            
        default:                                                    break;
    }
    
    MIDPickerKit *picker = [[MIDPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:dataArray];
    [_popView.footView addSubview:picker];
}

- (void)sendToPrinterAction {
    
    BOOL isDoubleWidth  = [_parameterArray[0] boolValue];
    BOOL isDoubleHeight = [_parameterArray[1] boolValue];
    BOOL isUnderLine    = [_parameterArray[2] boolValue];
    BOOL isBold         = [_parameterArray[3] boolValue];
    BOOL isMini         = [_parameterArray[4] boolValue];
    BOOL isReverse      = [_parameterArray[5] boolValue];
    
    int leftMargin      = [_parameterArray[8] intValue];
    int alignment       = [_parameterArray[9] intValue];
    
    HPRTFunctionESC *esc = [[HPRTFunctionESC alloc] init];
    HPRTCommandESC *cmdESC = [[HPRTCommandESC alloc] init];
    
    if (0 <= leftMargin) {
        
        NSData *formatData = [esc escPrintTextWithJustification:alignment Margin:leftMargin Font:isMini Emphasize:isBold DoubleHeight:isDoubleHeight DoubleWidth:isDoubleWidth Underline:isUnderLine ReverseMode:isReverse];
        
        NSData *textData = [cmdESC generateTextDataWithEncoding:_flatView.textView.text];
        [[HPRTDispatcher share] sendDataQueue:@[formatData,textData]];
        
        [self popSuccessView];
    }
}

- (void)popSuccessView {
    
    UIColor *headColor = PRTCOLOR_GRAY;
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.3 splitPercentage:0.3 headColor:headColor buttonColor:nil];
    _popView.titleLabel.text = @"Send Success";
    _popView.footView.backgroundColor = PRTCOLOR_COULD;
    
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH*0.6, SCREEN_HEIGHT*0.15)];
    label.text = @"Data send success";
    label.textColor = [UIColor grayColor];
    label.textAlignment = NSTextAlignmentCenter;
    label.backgroundColor = PRTCOLOR_COULD;
    [_popView.footView addSubview:label];
    
    __block MIDPopView *popView = _popView;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
    }];
    
    [_popView show];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
