//
//  HPRTTscBarcodeVC.m
//  HPRTPrinter
//
//  Created by midmirror on 16/3/3.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import "HPRTTscBarcodeVC.h"

@interface HPRTTscBarcodeVC ()

@property(strong,nonatomic,readwrite) UITableView *tableView;
@property(strong,nonatomic,readwrite) MIDFlatView *flatView;
@property(strong,nonatomic,readwrite) MIDPopView *popView;
@property(strong,nonatomic,readwrite) NSArray *barcodeTypeArray;
@property(strong,nonatomic,readwrite) NSArray *barcodeRotationArray;

@property(strong,nonatomic,readwrite) NSArray *commonOption;
@property(strong,nonatomic,readwrite) NSArray *barcodeOption;
@property(strong,nonatomic,readwrite) NSArray *qrcodeOption;

@property(strong,nonatomic,readwrite) NSMutableArray *commonDetailTitle;
@property(strong,nonatomic,readwrite) NSMutableArray *barcodeDetailTitle;
@property(strong,nonatomic,readwrite) NSMutableArray *qrcodeDetailTitle;

@property(strong,nonatomic,readwrite) NSString *barcodeType;
@property(strong,nonatomic,readwrite) NSString *barcodeReadable;
@property(strong,nonatomic,readwrite) NSString *barcodeRotation;
@property(strong,nonatomic,readwrite) NSString *barcodeX;
@property(strong,nonatomic,readwrite) NSString *barcodeY;
@property(strong,nonatomic,readwrite) NSString *barcodeHeight;
@property(strong,nonatomic,readwrite) NSString *barcodeNarrow ;
@property(strong,nonatomic,readwrite) NSString *barcodeWide;

@property(strong,nonatomic,readwrite) NSString *qrcodeMode;
@property(strong,nonatomic,readwrite) NSString *qrcodeModel;
@property(strong,nonatomic,readwrite) NSString *qrcodeEccLevel;
@property(strong,nonatomic,readwrite) NSString *qrcodeCellWidth;
@property(strong,nonatomic,readwrite) NSString *qrcodeMask;

@end

@implementation HPRTTscBarcodeVC

- (void)viewDidLoad {
    [super viewDidLoad];
    
    UILabel *titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 200, 44)];
    titleLabel.backgroundColor = [UIColor clearColor];
    titleLabel.font = [UIFont systemFontOfSize:20];
    titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    titleLabel.textAlignment = NSTextAlignmentCenter;
    titleLabel.text = @"TSC Barcode";
    self.navigationItem.titleView = titleLabel;
    
    [self setupDataSource];
    [self setupFlatView];
    [self setupFootTable];
}

- (void)viewWillAppear:(BOOL)animated {
    
    self.navigationController.navigationBar.barTintColor = PRTCOLOR_BLUE;
    [self.navigationController.navigationBar setTranslucent:NO];

}

- (void)printAction
{
    NSString *text = _flatView.textView.text;

    HPRTCommandTSPL *tsc = [[HPRTCommandTSPL alloc] init];
    
    NSLog(@"x:%@,y:%@,type:%@,height:%@,readable:%@,rotation:%@,narrow:%@,wide:%@,codenumber:%@",_barcodeX,_barcodeY,_barcodeType,_barcodeHeight,_barcodeReadable,_barcodeRotation,_barcodeNarrow,_barcodeWide,text);
    
    [tsc initCMDQueue];
    
    [tsc setPrintAreaSizeWithWidth:@"100" Height:@"80"];
    [tsc setCLS];
    
    if ([_barcodeType isEqualToString:@"QRCode"]) { //打印二维码
        
        [tsc printQRcodeWithXPos:_barcodeX
                            YPos:_barcodeY
                        EccLevel:_qrcodeEccLevel
                       CellWidth:_qrcodeCellWidth
                            Mode:_qrcodeMode
                        Rotation:_barcodeRotation
                           Model:_qrcodeModel
                            Mask:_qrcodeMask
                            Text:text];
    }else {
        
        [tsc printBarcodeWithXPos:_barcodeX
                             YPos:_barcodeY
                             Type:_barcodeType
                           Height:_barcodeHeight
                    HumanReadable:_barcodeReadable
                         Rotation:_barcodeRotation
                           Narrow:_barcodeNarrow
                             Wide:_barcodeWide
                       CodeNumber:text];
    }
    
    [tsc printWithSets:@"1" Copies:@"1"];
    
    [tsc sendCMDQueue];
}

- (void)setupFlatView {
    
    UIColor *headColor = PRTCOLOR_BLUE;
    UIColor *footColor = PRTCOLOR_COULD;
    
    _flatView = [[MIDFlatView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.4 headColor:headColor footColor:footColor];
    [self.view addSubview:_flatView];
    
    [_flatView.textView setText:@"123456789"];
    
    [_flatView.textView mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view.mas_centerX);
        make.top.equalTo(self.view.mas_top).offset(SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH * 0.8, SCREEN_WIDTH * 0.15));
    }];
    
    _flatView.mainButton.hidden = NO;
    [_flatView.mainButton setTitle:@"Send To Print" forState:UIControlStateNormal];
    [_flatView.mainButton addTarget:self action:@selector(printAction) forControlEvents:UIControlEventTouchUpInside];
    
    MIDScreenFit *fit = [[MIDScreenFit alloc] init];
    CGFloat buttonWidth = [fit getMainButtonWidth];
    CGFloat buttonHeight = [fit getMainButtonHeight];
    
    [_flatView.mainButton mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view);
        make.bottom.equalTo(_flatView.headView.mas_bottom).offset(-SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(buttonWidth, buttonHeight));
    }];
}

- (void)setupDataSource {
    
    _barcodeType = @"128";
    _barcodeReadable = @"0";
    _barcodeRotation = @"0";
    _barcodeX = @"0";
    _barcodeY = @"0";
    _barcodeHeight = @"80";
    _barcodeNarrow = @"2";
    _barcodeWide = @"2";
    
    _qrcodeMode = @"M";
    _qrcodeModel = @"M1";
    _qrcodeEccLevel = @"L";
    _qrcodeCellWidth = @"5";
    _qrcodeMask = @"S7";
    
    _barcodeTypeArray = @[@"128",@"128M",@"EAN128",@"25",@"25C",@"39",@"39C",@"39S",@"QRCode"];
    _barcodeRotationArray = @[@"0",@"90",@"180",@"270"];
    
    _commonOption = @[@"Rotation",@"X Coordinate",@"Y Coordinate"];
    _barcodeOption = @[@"Human Readable",@"Narrow (2-6 Dots)",@"Wide (2-6 Dots)",@"Height (1-255)"];
    _qrcodeOption = @[@"Mode",@"Model",@"ECC Level",@"Cell Width (1-10)",@"Mask (s0-s8)"];
    
    _commonDetailTitle = [[NSMutableArray alloc] initWithObjects:@"0",@"0",@"0",nil];
    _barcodeDetailTitle = [[NSMutableArray alloc] initWithObjects:@"can't be read",@"2",@"2",@"80",nil];
    _qrcodeDetailTitle = [[NSMutableArray alloc] initWithObjects:@"M",@"M1",@"L",@"5",@"S7",nil];
}

- (void)setupFootTable {
    
    _tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    
    UIScrollView *scrollView = [[UIScrollView alloc] initWithFrame:self.view.bounds];
    scrollView.scrollEnabled = YES;
    scrollView.contentSize = CGSizeMake(_flatView.footView.bounds.size.width, _flatView.footView.bounds.size.height * 2);
    [_flatView.footView addSubview:scrollView];
    [scrollView addSubview:_tableView];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return 3;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    if (section == 0) {
        return 1;
    }else if (section == 1) {
        return 3;
    }else {
        
        if ([_barcodeType isEqualToString:@"QRCode"]) {
            return _qrcodeOption.count;
        }else {
            return _barcodeOption.count;
        }
    }
}

- (nullable NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    
    if (section == 0) {
        return @"Type";
    }else if (section == 1){
        return @"Common Option";
    }else {
        return @"Barcode Option";
    }
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    
    return [[MIDScreenFit share] getRowHeight]*0.7;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    
    return 1;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"TSCBarcodeCell";
    MIDTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[MIDTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    if (indexPath.section == 0) {
        
        tableCell.textLabel.text = @"Barcode Type";
        tableCell.detailTextLabel.text = _barcodeType;
    }else if (indexPath.section == 1) {
        
        tableCell.textLabel.text = _commonOption[indexPath.row];
        tableCell.detailTextLabel.text = _commonDetailTitle[indexPath.row];
    }else {
        
        if ([_barcodeType isEqualToString:@"QRCode"]) {
            
            tableCell.textLabel.text = _qrcodeOption[indexPath.row];
            tableCell.detailTextLabel.text = _qrcodeDetailTitle[indexPath.row];
        }else {
            
            tableCell.textLabel.text = _barcodeOption[indexPath.row];
            tableCell.detailTextLabel.text = _barcodeDetailTitle[indexPath.row];
        }
    }
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    
    return tableCell;
}


#pragma mark UITableViewDelegate

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [[MIDScreenFit share] getRowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *buttonColor = PRTCOLOR_COULD;
    
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor buttonColor:buttonColor];
    _popView.titleLabel.text = @"Please Select";
    
    __block MIDPopView *popView = _popView;
    __block HPRTTscBarcodeVC *tscBarcodeVC = self;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
        [tscBarcodeVC updateTitleAndParameterAtSection:[NSNumber numberWithInteger:indexPath.section] Row:[NSNumber numberWithInteger:indexPath.row]];
        [tscBarcodeVC.tableView reloadData];
    }];
    
    [_popView show];
    
    MIDToolBox *tool = [[MIDToolBox alloc] init];
    
    NSArray *dataArray;
    NSArray *readable = @[@"can't be read",@"can be read"];
    
    if (indexPath.section == 0) {
        
        dataArray = @[_barcodeTypeArray];
        
    }else if (indexPath.section == 1) {
        
        switch (indexPath.row) {
            case 0: dataArray = @[_barcodeRotationArray];                    break;
            case 1: dataArray = [tool generateNumberArrayWith:@300];    break;
            case 2: dataArray = [tool generateNumberArrayWith:@300];    break;
                
            default:                                                    break;
        }
    }else {
        
        if ([_barcodeType isEqualToString:@"QRCode"]) {
            
            NSArray *mode = @[@"Auto",@"A",@"M"];
            NSArray *model = @[@"M1",@"M2"];
            NSArray *eccLevel = @[@"L",@"M",@"Q",@"H"];
            NSArray *mask = @[@"S0",@"S1",@"S2",@"S3",@"S4",@"S5",@"S6",@"S7",@"S8"];

            switch (indexPath.row) {
                case 0: dataArray = @[mode];       break;
                case 1: dataArray = @[model];      break;
                case 2: dataArray = @[eccLevel];   break;
                case 3: dataArray = [tool generateNumberArrayWith:@10]; break;
                case 4: dataArray = @[mask];       break;
                    
                default:                        break;
            }
            
        }else {
            
            switch (indexPath.row) {
                case 0: dataArray = @[readable];                            break;
                case 1: dataArray = [tool generateNumberArrayWith:@8];      break;
                case 2: dataArray = [tool generateNumberArrayWith:@8];      break;
                case 3: dataArray = [tool generateNumberArrayWith:@255];    break;
                    
                default:                                                    break;
            }
        }
    }
    
    
    MIDPickerKit *picker = [[MIDPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:dataArray];
    [_popView.footView addSubview:picker];
}


- (void)updateTitleAndParameterAtSection:(NSNumber *)section Row:(NSNumber *)row {
    
    if (section) {
        
        int rowInt = [row intValue];
        int sectionInt = [section intValue];
        
        MIDToolBox *tool = [[MIDToolBox alloc] init];
        NSString *newDetailTitle = [tool pieceStringWithArray:[MIDPickerKitModel share].titleArray];
        
        if (sectionInt == 0) {
            
            _barcodeType = newDetailTitle;
            
        }else if (sectionInt == 1){
            
            newDetailTitle = [tool getFormatNumber:newDetailTitle];
            [_commonDetailTitle replaceObjectAtIndex:rowInt withObject:newDetailTitle];
            
            switch (rowInt) {
                case 0: _barcodeRotation = newDetailTitle;      break;
                case 1: _barcodeX = newDetailTitle;             break;
                case 2: _barcodeY = newDetailTitle;             break;
                    
                default:
                    break;
            }
            
        }else {
            
            if ([_barcodeType isEqualToString:@"QRCode"]) {
                
                if (rowInt == 3) {
                    newDetailTitle = [tool getFormatNumber:newDetailTitle];
                }
                [_qrcodeDetailTitle replaceObjectAtIndex:rowInt withObject:newDetailTitle];
                
                switch (rowInt) {
                    case 0: _qrcodeMode = newDetailTitle;      break;
                    case 1: _qrcodeModel = newDetailTitle;     break;
                    case 2: _qrcodeEccLevel = newDetailTitle;   break;
                    case 3: _qrcodeCellWidth = newDetailTitle;  break;
                    case 4: _qrcodeMask = newDetailTitle;       break;
                        
                    default:
                        break;
                }
            
            }else {
                
                if (rowInt == 3) {
                    newDetailTitle = [tool getFormatNumber:newDetailTitle];
                }
                [_barcodeDetailTitle replaceObjectAtIndex:rowInt withObject:newDetailTitle];
                switch (rowInt) {
                    case 0: _barcodeReadable = [[MIDPickerKitModel share].rowArray[0] stringValue];;     break;
                    case 1: _barcodeNarrow = newDetailTitle;       break;
                    case 2: _barcodeWide = newDetailTitle;         break;
                    case 3: _barcodeHeight = newDetailTitle;       break;
                        
                    default:
                        break;
                }
            }
        }
    }
}


@end
