//
//  HPRTTscTextVC.m
//  HPRTPrinter
//
//  Created by midmirror on 16/3/3.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import "HPRTTscTextVC.h"

@interface HPRTTscTextVC ()

@property(strong,nonatomic,readwrite) UITableView *tableView;
@property(strong,nonatomic,readwrite) MIDFlatView *flatView;
@property(strong,nonatomic,readwrite) MIDPopView *popView;
@property(strong,nonatomic,readwrite) NSArray *titleArray;
@property(strong,nonatomic,readwrite) NSMutableArray *detailTextArray;
@property(strong,nonatomic,readwrite) NSMutableArray *parameterArray;

@end

@implementation HPRTTscTextVC

- (void)viewDidLoad {
    [super viewDidLoad];
    
    UILabel *titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 200, 44)];
    titleLabel.backgroundColor = [UIColor clearColor];
    titleLabel.font = [UIFont systemFontOfSize:20];
    titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    titleLabel.textAlignment = NSTextAlignmentCenter;
    titleLabel.text = @"TSC Barcode";
    self.navigationItem.titleView = titleLabel;
    
    [self setupDataSource];
    [self setupFlatView];
    [self setupFootTable];
}

- (void)viewWillAppear:(BOOL)animated {
    
    self.navigationController.navigationBar.barTintColor = PRTCOLOR_BLUE;
    [self.navigationController.navigationBar setTranslucent:NO];
    
}

- (void)printAction
{
    NSString *text              = _flatView.textView.text;
    NSString *x                 = _detailTextArray[0];
    NSString *y                 = _detailTextArray[1];
    NSString *font              = _detailTextArray[2];
    NSString *rotation          = _detailTextArray[3];
    NSString *xMultiplication   = _detailTextArray[4];
    NSString *yMultiplication   = _detailTextArray[5];
    
    NSLog(@"detailTextArray:%@",_detailTextArray);
    
    HPRTCommandTSPL *tsc = [[HPRTCommandTSPL alloc] init];
    
    [tsc initCMDQueue];
    
    [tsc setPrintAreaSizeWithWidth:@"100" Height:@"80"];
    [tsc setCLS];
    [tsc printTexTWithXPos:x YPos:y Font:font Rotation:rotation XMultiplication:xMultiplication YMultiplication:yMultiplication Text:text];
    [tsc printWithSets:@"1" Copies:@"1"];
    
    [tsc sendCMDQueue];
}

- (void)setupFlatView {
    
    UIColor *headColor = PRTCOLOR_BLUE;
    UIColor *footColor = PRTCOLOR_COULD;
    
    _flatView = [[MIDFlatView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.4 headColor:headColor footColor:footColor];
    [self.view addSubview:_flatView];
    
    [_flatView.textView setText:@"钥匙串访问（左上）-> 证书助理 -> 从证书颁发机构请求证书文件，电子邮箱可以随便填写，但是最好填写开发者账号的邮箱然后存储到磁盘，然后在开发者中心需要申请证书的时候，自己上传到苹果服务器"];
    
    [_flatView.textView mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view.mas_centerX);
        make.top.equalTo(self.view.mas_top).offset(SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH * 0.8, SCREEN_WIDTH * 0.15));
    }];
    
    _flatView.mainButton.hidden = NO;
    [_flatView.mainButton setTitle:@"Send To Print" forState:UIControlStateNormal];
    [_flatView.mainButton addTarget:self action:@selector(printAction) forControlEvents:UIControlEventTouchUpInside];
    
    MIDScreenFit *fit = [[MIDScreenFit alloc] init];
    CGFloat buttonWidth = [fit getMainButtonWidth];
    CGFloat buttonHeight = [fit getMainButtonHeight];
    
    [_flatView.mainButton mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view);
        make.bottom.equalTo(_flatView.headView.mas_bottom).offset(-SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(buttonWidth, buttonHeight));
    }];
}

- (void)setupDataSource {
    
    _titleArray = @[@"X Coordinate",@"Y Coordinate",@"Font",@"Rotation (Degrees)",@"X Multiplication (1-10)",@"Y Multiplication (1-10)"];
    _detailTextArray = [[NSMutableArray alloc] initWithObjects:@"0",@"0",@"3",@"0",@"1",@"1", nil];
}

- (void)setupFootTable {
    
    _tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    
    UIScrollView *scrollView = [[UIScrollView alloc] initWithFrame:self.view.bounds];
    scrollView.scrollEnabled = YES;
    scrollView.contentSize = CGSizeMake(_flatView.footView.bounds.size.width, _flatView.footView.bounds.size.height * 2);
    [_flatView.footView addSubview:scrollView];
    [scrollView addSubview:_tableView];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    return _titleArray.count;
}

//- (nullable NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
//    
//}

//- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
//    
//    return [[MIDScreenFit share] getRowHeight]*0.7;
//}
//
//- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
//    
//    return 1;
//}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"TSCBarcodeCell";
    MIDTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[MIDTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    tableCell.textLabel.text =_titleArray[indexPath.row];
    tableCell.detailTextLabel.text = _detailTextArray[indexPath.row];
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    
    return tableCell;
}


#pragma mark UITableViewDelegate

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [[MIDScreenFit share] getRowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    UIColor *headColor = PRTCOLOR_GRAY;
    UIColor *buttonColor = PRTCOLOR_COULD;
    
    _popView = [[MIDPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor buttonColor:buttonColor];
    _popView.titleLabel.text = @"Please Select";
    
    __block MIDPopView *popView = _popView;
    __block HPRTTscTextVC *tscTextVC = self;
    [_popView addButtonWithTitle:@"OK" handler:^(MIDPopViewButton *button) {
        
        [popView hideAnimation];
        [tscTextVC updateTitleAndParameterAtSection:[NSNumber numberWithInteger:indexPath.section] Row:[NSNumber numberWithInteger:indexPath.row]];
        [tscTextVC.tableView reloadData];
    }];
    
    [_popView show];
    
    MIDToolBox *tool = [[MIDToolBox alloc] init];
    
    NSArray *dataArray;
    
    NSArray *font = @[@"0",@"1",@"2",@"3",@"4",@"5",@"6",@"7",@"8",@"ROMAN.TTF"];
    
    switch (indexPath.row) {
        case 0: dataArray = [tool generateNumberArrayWith:@255];     break;
        case 1: dataArray = [tool generateNumberArrayWith:@255];     break;
        case 2: dataArray = @[font];                                 break;
        case 3: dataArray = @[@[@"0",@"90",@"180",@"270"]];          break;
        case 4: dataArray = [tool generateNumberArrayWith:@10];      break;
        case 5: dataArray = [tool generateNumberArrayWith:@10];      break;
            
        default:                        break;
    }
    
    MIDPickerKit *picker = [[MIDPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:dataArray];
    [_popView.footView addSubview:picker];
}


- (void)updateTitleAndParameterAtSection:(NSNumber *)section Row:(NSNumber *)row {
    
    if (section) {
        
        int rowInt = [row intValue];
        
        MIDToolBox *tool = [[MIDToolBox alloc] init];
        NSString *newDetailTitle = [tool pieceStringWithArray:[MIDPickerKitModel share].titleArray];
        
        if ((rowInt < 2) || (rowInt >3)) {
            newDetailTitle = [tool getFormatNumber:newDetailTitle];
        }
        [_detailTextArray replaceObjectAtIndex:rowInt withObject:newDetailTitle];
    }
}

@end
