//
//  HPRTCommandESC.h
//  HPRTSDK
//
//  Created by midmirror on 16/3/10.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 *  ESC-POS 指令集:大约200个生成指令的函数。
 */
@interface HPRTCommandESC : NSObject

/**
 *  初始化指令队列
 */
- (void)initCMDQueue;

/**
 *  获取生成的指令
 *
 *  @return 生成的指令 data
 */
- (NSData *)generateCMDData;

/**
 *  生成编码后的文本数据
 *
 *  @param text
 *
 *  @return 编码后的文本 data
 */
- (NSData *)generateTextDataWithEncoding:(NSString *)text;

/**
 *  将编码后的文本数据加入指令队列
 */
- (void)escAddTextDataToCMDQueue:(NSString *)text;

- (void)escPrintAndLineFeed;

- (void)escPrintAndReturnStandardMode;

- (void)escPrintAndCarriageReturn;

- (void)escPrintDataInPageMode;

/**
 *  page 73.
 *  @param distance (0~255)
 */
- (void)escPrintAndFeedPaperWithDistance:(int)distance;

/**
 *  page 76.
 *  @param distance (0~48)
 */
- (void)escPrintAndReverseFeedWithDistance:(int)distance;

/**
 *  page 78.
 *  @param lines (0~255)
 */
- (void)escPrintAndFeedLines:(int)lines;

/**
 *  page 80.
 *  @param lines (0~2)
 */
- (void)escPrintAndReverseFeedLines:(int)lines;

/**
 *  page 83.
 *  @param lines (0~2)
 */
- (void)escSelectDefaultLineSpacing;

/**
 *  page 85.
 *  @param spacing (0~255)
 */
- (void)escSetLineSpacing:(int)spacing;

#pragma mark Character Commands

- (void)escCancelPrintDataInPageMode;

/**
 *  page 91.
 *  @param spacing (0~255)
 */
- (void)escSetRightSideCharacterSpacing:(int)spacing;

/**
 *  page 93.
 *  @param mode (0~255)
 */
- (void)escSelectPrintMode:(int)mode;

/**
 *  page 98.
 *  n = 0, character set cancel     [default]
 *  n = 1, character set selected
 *  @param n (0~255) ???
 */
- (void)escSelectOrCancelUserDefinedCharacterSet:(int)mode;

/**
 *  page 99.
 *  @param code_start (32~126)
 *  @param code_end   (32~126)
 *  @param horizontal ()
 */
- (void)escDefineUserDefinedCharactersWithCodeStart:(int)code_start
                                            CodeEnd:(int)code_end
                                         Horizontal:(int)horizontal;

/**
 *  page 104.
 *  0,48 turns off underline mode
 *  1,49 turns on underline mode (1-dot thick)
 *  2,50 turns on underline mode (2-dots thick)
 *  @param mode (0~2,48~50)
 */
- (void)escTurnUnderlineMode:(int)mode;

/**
 *  page 106.
 *  @param n (32~126)
 */
- (void)escCancelUserDefinedCharacters:(int)n;

/**
 *  page 108.
 *  n = 0 [default]
 *  @param mode (0~255)
 */
- (void)escTurnEmphasizedMode:(int)mode;

/**
 *  page 109.
 *  n = 0 [default]
 *
 *  @param mode (0~255)
 */
- (void)escTurnDoubleStrikeMode:(int)mode;

/**
 *  page 110.
 *  @param font (0~2),(48~50)
 */
- (void)escSelectCharacterFont:(int)font;

/**
 *  page 115.
 *  @param n (n<=15)
 */
- (void)escSelectInternationalCharacterSet:(int)n;

/**
 *  page 117.
 *  @param mode (0~2),(48~50)
 */
- (void)escTurn90ClockwiseRotationMode:(int)mode;

/**
 * page 119.
 * n = 0 [default]
 * 0,48 black
 * 1,49 red
 *  @param n (0,1,48,49)
 */
- (void)escSelectPrintColor:(int)color;

/**
 *  page 121.
 *
 *  @param table (0~8),(16~19)
 */
- (void)escSelectCharacterCodeTable:(int)table;

/**
 *  page 124.
 *  @param mode (0~255)
 */
- (void)escTurnUpsideDownPrintMode:(int)mode;

#pragma mark GS ( N

/**
 *  page 128.
 *  color = 49 [default]
 *
 *  @param color
 */
- (void)escSelectCharacterColor:(int)color;

/**
 *  page 130.
 *  m = 48 [default]
 *  48 none; 49 clolor1; 50 color2; 51 color3
 *  @param m
 */
- (void)escSelectBackgroundColor:(int)color;

/**
 *  page 132.
 *  48 none; 49 clolor1; 50 color2; 51 color3
 *
 *  @param m (0,1,48,49)
 */
- (void)escTurnShadingMode:(int)mode;

/**
 *  page 134.
 *  n = 0 [default]
 *
 *  @param n
 */
- (void)escSelectCharacterSize:(int)size;

/**
 * page 136.
 *  n = 0 [default]
 *
 *  @param n (0~255)
 */
- (void)escTurnWhiteBlackReversePrintMode:(int)reverse_mode;

/**
 *  page 138.
 *  mode = 0 [default]
 *
 *  @param mode (0~255)
 */
- (void)escTurnSmoothingMode:(int)mode;

#pragma mark Panel Button Commands

/**
 *  page.140
 *  n = 0 enable [default]
 *  n = 1 disable
 *
 *  @param n (0~255)
 */
- (void)escSetPanelButtonMode:(int)mode;

/**
 *  page 145.
 *
 *  @param n (0~255)
 */
- (void)escSelectPaperSonsorsToOutputPaperEndSingals:(NSString *)n;

/**
 *  page 147.
 *
 *  @param n (0~255)
 */
- (void)escSelectPaperSonsorsToStopPrinting:(int)n;

#pragma mark Print Positioin Commands

/**
 *  page 151.
 */
- (void)escSetHorizontalTab;

/**
 *  page 152.
 *
 *  @param nl (0~255)
 *  @param nh (0~255)
 */
- (void)escSetAbsolutePrintPosition:(int)position;

/**
 *  page 154.
 *
 *  @param n (1~255)
 *  @param k (0~32)
 */
- (void)escSetHorizontalTabPositionsData:(NSData *)data;

/**
 *  page 156.
 
 *  0,48 left to right
 *  1,49 bottom to top
 *  2,50 right to left
 *  3,51 top to bottom
 
 *  @param n (0~3),(48~51)
 */
- (void)escSelectPrintDirectionInPageMode:(int)direction;

/**
 *  page 158.
 *  设置页模式打印范围
 *
 *  @param horizontal
 *  @param vertical
 *  @param width
 *  @param height
 */
- (void)escSetPrintAreaInPageModeWithHorizontal:(int)horizontal
                                       Vertical:(int)vertical
                                          Width:(int)width
                                         Height:(int)height;

/**
 *  page 163.
 *
 *  @param nl
 *  @param nh
 */
- (void)escSetRelativePrintPosition:(int)position;

/**
 *  page 165.
 *  n = 0 [default]
 *  0,48 left justification
 *  1,49 centered
 *  2,50 right justification
 *
 *  @param n (0~2),(48~50)
 */
- (void)escSelectJustification:(int)justification;

/**
 *  page 167.
 *  @param nl (0~255)
 *  @param nh (0~255)
 */
- (void)escSetAbsoluteVerticalPrintPostionInPageMode:(int)position;

/**
 *  page 169.
 *
 *  @param left_margin 左对齐
 */
- (void)escSetLeftMargin:(int)left_margin;

/**
 *  page 171.
 *  0,48 cancel data in the current print buffer.
 *  1,49 print data in the current print buffer.
 *
 *  @param n (0,1,48,49)
 */
- (void)escSetPrintPositionToTheBeginingOfPrintLine:(int)mode;

/**
 *  page 173.
 *
 *  @param nl
 *  @param nh
 */
- (void)escSetPrintAreaWidth:(int)width;

/**
 *  page 177.
 *  @param nl
 *  @param nh
 */
- (void)escSetRelativeVerticalPrintPositionInPageMode:(int)position;

#pragma mark Bit Image Commands

/**
 *  page 180.
 *  @param m
 *  @param data
 */
- (void)escSelectBitImageMode:(int)mode ImageWidth:(int)width Data:(NSData *)data;

/**
 *  page 194.
 *
 *  @param n (1~255)
 *  @param m (0,48:Normal),(1,49:Double-width),(2,50:Double-height),(3,51:Quadruple)
 */
- (void)escPrintNVBitImage:(int)img_id Mode:(int)mode;

/**
 *  page 210.
 *
 *  @param m  48
 *  @param fn 0,48
 */
- (void)escTransmitNVGraphicsMemoryCapacityFN:(NSString *)fn;

/**
 *  page 212.
 *
 *  @param m  48
 *  @param fn 1,49
 *  @param x  50,51
 *  @param y  50,51(必须和 x 同样大)
 */
- (void)escSetReferenceDotDensityForGraphicsFN:(int)fn X:(int)x Y:(int)y;

/**
 *  page 214.
 *
 *  @param m  48
 *  @param fn 2,50
 */
- (void)escPirntGraphicsDataInPrintBufferFN:(int)fn;

/**
 *  page 215.
 *
 *  @param fn 3,51
 */
- (void)escTransmitRemainingCapacityOfNVGraphicsMemoryFN:(int)fn;

/**
 *  page 216.
 *
 *  @param fn 4,53
 */
- (void)escTransmitRemainingCapacityOfDownloadGraphicsMemoryFN:(int)fn;

/**
 *  page 218.
 */
- (void)escTransmitKeyCodeListForDefinedNVGraphics;

/**
 *  page 220.
 */
- (void)escDeleteAllNVGraphicsData;

/**
 *  page 221.
 *
 *  @param kc1 (32~126)
 *  @param kc2 (32~126)
 */
- (void)escDeleteSpecifiedNVGraphicsDataKC1:(int)kc1 KC2:(int)kc2;

/**
 *  222
 *
 */
- (void)escDefineNVGraphicsDataRasterFormatKC1:(int)kc1
                                           KC2:(int)kc2
                                    ImageWidth:(int)image_width
                                   ImageHeight:(int)image_height
                                     ImageData:(NSData *)imageData;

/**
 *  page 227.
 *
 *  @param kc1
 *  @param kc2
 *  @param image_width
 *  @param image_height
 *  @param imageData    生成的图片数据
 */
- (void)escDefineNVGraphicsDataColumnFormatKC1:(int)kc1
                                           KC2:(int)kc2
                                    ImageWidth:(int)image_width
                                   ImageHeight:(int)image_height
                                     ImageData:(NSData *)imageData;

/**
 *  page 231.
 *
 *  @param kc1 (32~126)
 *  @param kc2 (32~126)
 *  @param x   1,2
 *  @param y   1,2
 */
- (void)escPrintSpecifiedNVGraphicsDataKC1:(int)kc1 KC2:(int)kc2 X:(int)x Y:(int)y;

/**
 *  page 238.
 */
- (void)escTransmitKeyCodeListForDefinedDownloadGraphics;

/**
 *  page 240
 */
- (void)escDeleteAllGraphnicsData;

/**
 *  page 241.
 *
 *  @param kc1 (32~126)
 *  @param kc2 (32~126)
 */
- (void)escDeleteSpecifiedDownloadGraphicsDataKC1:(int)kc1 KC2:(int)kc2;

/**
 *  page 242.
 *
 *  @param kc1 (32~126)
 *  @param kc2 (32~126)
 *  @param b
 *  @param x
 *  @param y
 */
- (void)escDefineDownloadedGraphicsDataRasterFormatKC1:(int)kc1
                                                   KC2:(int)kc2
                                                     B:(int)b
                                                     X:(int)x
                                                     Y:(int)y
                                                  Data:(NSData *)data;

/**
 *  page 246.
 */
- (void)escDefineDownloadedGraphicsDataColumnFormatKC1:(int)kc1
                                                   KC2:(int)kc2
                                                     B:(int)b
                                                     X:(int)x
                                                     Y:(int)y
                                                  Data:(NSData *)data;

/**
 *  page 250.
 */
- (void)escPrintSpecifiedDownloadGraphicsDataKC1:(int)kc1 KC2:(int)kc2 X:(int)x Y:(int)y;

/**
 *  page 252
 */
- (void)escStoreGraphicsDataInPrinterBufferRasterFormatBX:(int)bx
                                                       BY:(int)by
                                                        C:(int)c
                                                        X:(int)x
                                                        Y:(int)y
                                                     Data:(NSData *)data;

/**
 *  page 261.
 */
- (void)escStoreGraphicsDataInPrinterBufferColumnFormatBX:(int)bx
                                                       BY:(int)by
                                                        C:(int)c
                                                        X:(int)x
                                                        Y:(int)y
                                                     Data:(NSData *)data;

/**
 *  page 264.
 *
 *  @param n    (1~255)
 */
- (void)escDefineNVBitImage:(int)n Data:(NSData *)data;

/**
 *  page 268.
 */
- (void)escPrintRasterBitImageM:(NSString *)m X:(int)x Y:(int)y;

/**
 *  page 273
 *
 *  @param x    (1~255)
 *  @param y    (1~255)
 *  @param data
 */
- (void)escDefineDownloadedBitImageX:(int)x Y:(int)y Data:(NSData *)data;

/**
 *  page 276.
 *
 *  (0,48:Normal),(1,49:Double-width),(2,50:Double-height),(3,51:Quadruple)
 *
 *  @param m (0~3),(48~51)
 */
- (void)escPrintDownloadedBitImageM:(int)m;

/**
 *  page 283.
 */
- (void)escPrintVariableVerticalSizeBitImageM:(int)m ImageWidth:(int)width ImageHeight:(int)height Data:(NSData *)data;

#pragma mark Status Commands

/**
 *  page 288.
 */
- (void)escTransmitRealTimeStatus:(int)n;

/**
 *  page 305.
 */
- (void)escTransmitPeripheralDeviceStatus:(int)n;

/**
 *  page 306.
 */
- (void)escTransmitPaperSonsorStatus;

/**
 *  page 308.
 *
 *  @param m (0~255)
 */
- (void)escSetAutomaticStatusBackMode:(int)mode;

/**
 *  page 322.
 *
 *  @param n (0~255)
 */
- (void)escSetAutomaticStatusBackForInk:(int)n;

/**
 *  page 327.
 * 1,49: transmits paper sensor status
 * 2,50: transmits drawer kick-out connector status
 * 4,52: transmits ink status
 *
 *  @param m (1,2,4,49,50,52)
 */
- (void)escTransmitStatusMode:(int)mode;

#pragma mark Bar Code Commands

/**
 *  page 332.
 *  0,48 Not Printed
 *  1,49 above the bar code
 *  2,50 below the bar code
 *  3,51 both above and below the bar code
 *
 *  @param m (0~3),(48~51)
 */
- (void)escSelectPrintPositionOfHRICharacers:(int)position;

/**
 *  page 334.
 *  0,48 font a
 *  1,49 font b
 *  2,50 font c
 *
 *  @param n (0~2),(48~50)
 */
- (void)escSelectFontForHRICharacters:(int)font;

/**
 *  page 337.
 *
 *  @param n (1~255)
 */
- (void)escSetBarCodeHeight:(int)height;

/**
 *  page 339.
 *
 *  @param type   (A:0~6),(B:65~73)
 */
- (void)escPrintBarCodeWithType:(int)type Barcode:(NSString *)barcode;

/**
 *  page 355.
 *
 *  @param width (2~6),(68~76)
 */
- (void)escSetBarCodeWidth:(int)width;

#pragma mark Macro Function Commands

/**
 *  page 360.
 */
- (void)escStartOrEndMacroDefinition;

/**
 *  page 362.
 *
 *  @param times      (1~255)
 *  @param wait_times (0~255)
 *  @param mode       (0,1)
 */
- (void)escExecuteMacroWithTimes:(int)times WaitTimes:(int)wait_times Mode:(int)mode;

#pragma mark Mechanism Control Commands

/**
 *  page 366.
 */
- (void)escReturnHome;

/**
 *  page 367.
 *
 *  @param mode (0~255)
 */
- (void)escTurnUnidirectionalPrintMode:(int)mode;

/**
 *  page 368.
 */
- (void)escPartialCutOnePointLeftUncut;

/**
 *  page 370.
 */
- (void)escPartialCutThreePointsLeftUncut;

/**
 *  page 362.
 *
 *  @param mode (0,1,48,49)
 */
- (void)escSelectCutMode:(int)mode;

#pragma mark Miscellaneous Commands

/**
 *  page 380.
 *
 *  @param request (1~2)
 */
- (void)escSendRealTimeRequestToPrinter:(int)request;

/**
 *  page 385
 *
 *  @param mode 0,1
 *  @param time (1~8)
 */
- (void)escGeneratePulseInReleTimeMode:(int)mode Time:(int)time;

/**
 *  page 388
 */
- (void)escExecutePowerOffSequence;

/**
 *  page 391
 *
 *  @param status 1,5
 */
- (void)escTransmitSpecifiedStatusInRealTime:(int)status;

/**
 *  page 396
 */
- (void)escClearBuffer;

/**
 *  page 405
 *
 *  @param times (0~63)
 *  @param t1    (0~255)
 *  @param t2    (0~255)
 */
- (void)escBeepIntegratedBeeperWithTimes:(int)times T1:(int)t1 T2:(int)t2;

/**
 *  page 406
 *
 *  @param a     (48~51)
 *  @param times 0,255
 *  @param t1    (1~50,255)
 *  @param t2    (1~50)
 */
- (void)escSetIntegratedBeeperWhenOfflineFactorsOccurA:(int)a Times:(int)times T1:(int)t1 T2:(int)t2;

/**
 *  page 408
 *
 *  @param times 0,255
 *  @param t1    (1~50,255)
 *  @param t2    (1~50)
 */
- (void)escSetIntegratedBeeperExceptWhenOfflineFactorsOccurWithTimes:(int)times T1:(int)t1 T2:(int)t2;

/**
 *  page 410.
 *  1,3 enables printer
 *  2   disables printer
 *
 *  @param n (1~3)
 */
- (void)escSelectPeripheralDevice:(int)mode;

/**
 *  page 412.
 */
- (void)escInitializePrinter;

/**
 *  page 413.
 */
- (void)escSelectPageMode;

/**
 *  page 416.
 */
- (void)escSelectStandardMode;

/**
 *  page 418
 *  0,48: drawer kick-out connector pin 2
 *  1,49: drawer kick-out connector pin 5
 *
 *  @param pin_mode 0,1,48,49
 *  @param on_time  (0~255)
 *  @param off_time (0~255)
 */
- (void)escGeneratePulsePinMode:(int)pin_mode ONTime:(int)on_time OFFTime:(int)off_time;

/**
 *  page 420
 *
 *  @param type (0,1,2),(48,49,50)
 *  @param mode (1,2,3),(49,50,51),64
 */
- (void)escExecuteTestPrintType:(int)type Mode:(int)mode;

/**
 *  page 424.
 *
 *  @param length 3,5
 */
- (void)escSetRealTimeCommandData:(NSData *)data;

/**
 *  page 445.
 *  0,48:   print mode when power is turned on
 *  (1,49: mode1), (2,50:mode2), (3,51:mode3), (4,52:mode4)
 *
 *  @param mode (1,4),(48,52)
 */
- (void)tscSelectPrintControlMode:(int)mode;

/**
 *  page 448
 *
 *  @param mode (250~255),(0~6)
 */
- (void)escSelectPrintDensityMode:(int)mode;

/**
 *  page 451
 *
 *  @param mode (0~9),(48~57)
 */
- (void)escSelectPrintSpeedMode:(int)mode;

/**
 *  page 453.
 *
 *  @param number (0~4),(48~50),128
 */
- (void)escSelectNumbersOfPartsForThermalHeadEnergizing:(int)number;

/**
 *  page 456.
 */
- (void)escSetPrintableAreaWhenPageModeSelectedWX:(int)wx WY:(int)wy OX:(int)ox;

/**
 *  page 461.
 */
- (void)escDrawLineWithX1:(int)x1 Y1:(int)y1 X2:(int)x2 Y2:(int)y2 M1:(int)m1;

/**
 *  page 465.
 */
- (void)escDrawRectangleX1:(int)x1 Y1:(int)y1 X2:(int)x2 Y2:(int)y2 M1:(int)m1;

/**
 *  page 468.
 * (1,49: Printer model ID),(2,50: Type ID), (3,51: Version ID)
 *
 *  @param id_number (1~3),(49~51)
 */
- (void)escTransmitPrinterID:(int)id_number;

/**
 *  page 484
 *
 *  @param x
 *  @param y
 */
- (void)escSetHorizontalAndVerticalMotionUnitsX:(int)x Y:(int)y;

/**
 *  page 486.
 *
 *  @param nl
 *  @param nh
 */
- (void)escInitializeMaintenanceCounterN:(int)n;

/**
 *  page 488.
 */
- (void)escTransmitMaintenanceCounterN:(int)n;

/**
 *  page 493
 *
 *  @param wait_time1 (0~255) default 6
 *  @param wait_time2 (0~255) default 0
 */
- (void)escSetOnlineRecoveryWaitTime1:(int)wait_time1 WaitTime2:(int)wait_time2;

#pragma mark Kanji Commands

/**
 *  page 502.
 *
 *  @param mode (0~255) default:0
 */
- (void)escSelectKanjiCharactersPrintMode:(int)mode;

/**
 *  page 505.
 */
- (void)escSelectKanjiCharacterMode;

/**
 *  page 508.
 *
 *  @param mode (0~2),(48~50)
 */
- (void)escSelectKanjiCharacterFontMode:(int)mode;

/**
 *  page 510.
 *  0,48: turn off kanji underline mode
 *  1,49: turn on kanji underline mode(1-dot thick)
 *  2,50: turn on kanji underline mode(2-dots thick)
 *
 *  @param mode (0~2),(48~50)
 */
- (void)escTurnUnderlineModeForKanjiCharacters:(int)mode;

/**
 *  page 512.
 */
- (void)escCancelKanjiCharacterMode;

/**
 *  page 514.
 *
 *  @param c1
 *  @param c2
 */
- (void)escDefineUserDefinedKanjiCharactersC1:(int)c1 C2:(int)c2 Data:(NSData *)data;

/**
 *  page 518.
 *  0,48 JIS code
 *  1,49 SHIFT JIS code
 *
 *  @param mode (0,1),(48,49)
 */
- (void)escSelectKanjiCharacterCodeSystemMode:(int)mode;
/**
 *  page 520.
 *
 *  @param n1 (0~32) default:0
 *  @param n2 (0~32) default:0
 */
- (void)escSetKanjiCharacterSpacingN1:(int)n1 N2:(int)n2;

/**
 *  page 522.
 *
 *  @param mode (0~255)
 */
- (void)escTurnQuadrupleSizeModeForKanjiCharacters:(int)mode;

/**
 *  page 523.
 *
 *  @param c1
 *  @param c2
 */
- (void)escCancelUserDefinedKanjiCharactersC1:(int)c1 C2:(int)c2;

#pragma mark Two Dimension Code Commands

/**
 *  page 533.
 *
 *  @param columns (0~30) default:0
 */
- (void)escPDF417SetNumberOfColumnsInDataRegion:(int)columns;

/**
 *  page 535.
 *
 *  @param rows (3~90) default:0
 */
- (void)escPDF417SetNumberOfRows:(int)rows;

/**
 *  page 536.
 *
 *  @param width (2~8)
 */
- (void)escPDF417SetWidthOfModule:(int)width;

/**
 *  page 538.
 *
 *  @param row_height (2~8)
 */
- (void)escPDF417SetRowHeight:(int)row_height;

/**
 *  page 540
 *
 *  @param mode  48,49
 *  @param level 48,49,50(level 0, 1, 2)
 */
- (void)escPDF417SetErrorCorrectionLevelMode:(int)mode Level:(int)level;

/**
 *  page 543
 */
/**
 *  page 543.
 *  0:standard pdf417
 *  1:truncated pdf417
 *
 *  @param option 0,1 (0:standard pdf417)
 */
- (void)escPDF417SelectOptions:(int)option;

/**
 *  page 544.
 *
 *  @param pl
 *  @param ph
 */
- (void)escPDF417StoreDataInSymbolStorageData:(NSData *)data;

/**
 *  page 546.
 */
- (void)escPDF417PrintSymbolDataInSymbolStorageArea;

/**
 *  page 549.
 */
- (void)escTransmitSymbolDataSizeInSymbolStorageArea;
/**
 *  page 552
 *
 *  @param model 49,50 (49:model 1),(50:model 2)
 */
- (void)escQRCodeSelectModel:(int)model;

/**
 *  page 553
 *
 *  @param size (1~16)
 */
- (void)escQRCodeSetModuleSize:(int)size;

/**
 *  page 555
 *
 *  @param level (48~51: Level L,M,Q,H)
 */
- (void)escQRCodeSelectErrorCorrectionLevel:(int)level;

/**
 *  page 557
 *
 *  @param pl (0~255)
 *  @param ph (0~27)
 */
- (void)escQRCodeStoreDataInSymbolStorageAreaWithQRcode:(NSString *)qr_code;

/**
 *  page 559
 */
- (void)escQRCodePrintSymbolDataInSymbolStorageArea;

/**
 *  page 562
 */
- (void)escQRCodeTransmitSymbolDataSizeInSymbolStorageArea;

/**
 *  page 565.
 *
 *  @param mode (50~54: mode 2 ~ 6)
 */
- (void)escMaxiCodeSelectMode:(int)mode;

/**
 *  page 566.
 *
 *  @param pl   (4~141)
 *  @param ph   0
 */
- (void)escMaxiCodeStoreDataInSymbolStorageAreaData:(NSData *)data;

/**
 *  page 567.
 */
- (void)escMaxiCodePrintSymbolDataInSymbolStorageArea;

/**
 *  page 570.
 */
- (void)escMaxiCodeTransmitSymbolDataSizeInSymbolStorageArea;

/**
 *  page 573
 *
 *  @param width (2~8)
 */
- (void)escRSSSetModuleWidth:(int)width;

/**
 *  page 574.
 *
 *  @param width (2~8)
 */
- (void)esc2DimensionalRSSSetExpandedStackedMaximumWidth:(int)width;

/**
 *  page 575.
 *
 *  @param pl
 *  @param ph
 *  @param n    (72,73,76)
 *  @param data
 */
- (void)esc2DimensionalRSSStoreDataInSymbolStorageAreaN:(int)n Data:(NSData *)data;

/**
 *  page 577.
 */
- (void)esc2DimensionalRSSPrintSymbolDataInSymbolStorageArea;

/**
 *  page 579.
 */
- (void)esc2DimensionalRSSTransmitSymbolDataSizeInSymbolStorageArea;

/**
 *  page 582.
 *
 *  @param width (2~8)
 */
- (void)escCompositeSymbolSetModuleWidth:(int)width;

/**
 *  page 583.
 *
 *  @param width (2~8)
 */
- (void)escCompositeRSSSetExpandedStackedMaximumWidth:(int)width;

/**
 *  page 584.
 *  0,48: HRI characters are not added.
 *  1,49: HRI characters are added.(select font A)
 *  2,50: HRI characters are added.(select font B)
 *  3,51: HRI characters are added.(select font C)
 *
 *  @param font (0~3),(48~51)
 */
- (void)escCompositeSymbolSelectFontHRICharacters:(int)font;

/**
 *  page 586.
 *
 *  @param pl
 *  @param ph
 *  @param a    48,49
 *  @param b    (a = 48, b= (65~77)),(b = 49,b = 65,66)
 *  @param data
 */
- (void)escCompositeSymbolStoreDataInSymbolStorageAreaA:(int)a B:(int)b Data:(NSData *)data;

/**
 *  page 594
 */
- (void)escCompositeSymbolPrintSymbolDataInSymbolStorageArea;

/**
 *  page 600
 */
- (void)escCompositeSymbolTransmitSymbolDataSizeInSymbolStorageArea;

#pragma mark Customize Commands

/**
 *  page 606
 */
- (void)escWriteToNVUserMemoryAddress:(int)address Data:(NSData *)data;

/**
 *  page 608.
 */
- (void)escReadFromNVUserMemoryAddress:(int)address Length:(int)length;

/**
 *  page 615.
 *
 *  @param fn (0,48)
 *  @param c1 (32~126)
 *  @param c2 (32~126)
 */
- (void)escDeleteSpecifiedRecordFn:(int)fn C1:(int)c1 C2:(int)c2;

/**
 *  page 616.
 *
 *  @param pl
 *  @param ph
 *  @param fn   (1,49)
 *  @param c1   (32~126)
 *  @param c2   (32~126)
 *  @param data
 */
- (void)escStoreDataInSpecifiedRecordFN:(int)fn C1:(int)c1 C2:(int)c2 Data:(NSData *)data;

/**
 *  page 618.
 *
 *  @param fn (0,48)
 *  @param c1 (32~126)
 *  @param c2 (32~126)
 */
- (void)escTransmitDataInSpecifiedRecordFn:(int)fn C1:(int)c1 C2:(int)c2;

/**
 *  page 620.
 *
 *  @param fn 3,51
 */
- (void)escTransmitCapacityOfNVUserMemoryCurrentlyBeingUsedFN:(int)fn;

/**
 *  page 621.
 *
 *  @param fn 4,52
 */
- (void)escTransmitRemainingCapacityOfNVUserMemoryFN:(int)fn;

/**
 *  page 622.
 *
 *  @param fn 5,53
 */
- (void)escTransmitKeyCodeListFN:(int)fn;

/**
 *  page 624.
 *
 *  @param fn 6,54
 */
- (void)escDeleteAllDataInNVUserMemoryFN:(int)fn;

/**
 *  page 631.
 */
- (void)escChangeIntoUserSettingMode;

/**
 *  page 632.
 */
- (void)escEndUserSettingModeSession;
/**
 *  page 633.
 *
 *  @param pl (0~255)
 *  @param ph (0~255)
 */
- (void)escChangeMemorySwitchData:(NSData *)data;

/**
 *  page 646.
 *
 *  @param a (2,8)
 */
- (void)escTransmitMemorySwitchSettingA:(int)a;

/**
 *  page 648.
 *
 *  @param pl   (0~255)
 *  @param ph   (0~255)
 *  @param data
 */
- (void)escSetCustomizedSettingValuesData:(NSData *)data;

/**
 *  page 663.
 *
 *  @param a (1,2,3,5,6,97,116,118)
 */
- (void)escTransmitCustomizedSettingValuesA:(int)a;

/**
 *  page 666.
 *
 *  @param a  (10,12,17,18)
 *  @param d1 (30,31)
 *  @param d2 (30,31) d1 can't be euqual o d2!!
 */
- (void)escCopyUserDefinedPageA:(int)a D1:(int)d1 D2:(int)d2;

/**
 *  page 669.
 *
 *  @param pl   (0~255)
 *  @param ph   (0~255)
 *  @param y
 *  @param c1
 *  @param c2
 *  @param data
 */
- (void)escDefineColumnFormatDataForCharacterCodePageY:(int)y C1:(int)c1 C2:(int)c2 Data:(NSData *)data;

/**
 *  page 671.
 *
 *  @param pl   (0~255)
 *  @param ph   (0~255)
 *  @param x
 *  @param c1
 *  @param c2
 *  @param data
 */
- (void)escDefineRasterFormatDataForCharacterrCodePageX:(int)x C1:(int)c1 C2:(int)c2 Data:(NSData *)data;

/**
 *  page 673.
 *
 *  @param c1
 *  @param c2
 */
- (void)escDeleteDataForChracterCodePageC1:(int)c1 C2:(int)c2;

/**
 *  page 674.
 *
 *  @param pl   (3~8)
 *  @param ph   (0~255)
 *  @param a    (1~4),depend on data
 *  @param data
 */
- (void)escSetConfigurationItemForSerialInterfaceA:(int)a Data:(NSData *)data;

/**
 *  page 678.
 *
 *  @param pl   (2)
 *  @param ph   (0)
 *  @param a    (1~4)
 */
- (void)escTransmitConfigurationItemForSerialInterfacePL:(int)pl PH:(int)ph A:(int)a;

/**
 *  page 680.
 */
- (void)escSetConfigurationItemForBluetoothInterfaceA:(int)a Data:(NSData *)data;

/**
 *  page 682.
 *
 *  @param a (48,49,65)
 */
- (void)escTransmitConfigurationItemForBluetoothInterfaceA:(int)a;

/**
 *  page 685.
 *
 *  @param d1 62
 *  @param d2 76
 *  @param d3 82
 */
- (void)escDeletePaperLayoutD1:(int)d1 D2:(int)d2 D3:(int)d3;

/**
 *  page 686
 *
 *  @param pl (9~36)
 *  @param ph (0)
 *  @param sa (48,49,64)
 *  @param sb (135~3000)
 *  @param sc (25~100)
 *  @param sd (0~3000)
 *  @param se (0~3000)
 *  @param sf (38~3000)
 *  @param sg (when sa = '48' or '49':27~507),(when sa = '64':47~507)
 *  @param sh (when sa = '48' or '49':240~720),(when sa = '64':240~700)
 */
- (void)escSetPaperLayoutP:(int)p   SA:(int)sa SB:(int)sb SC:(int)sc
                        SD:(int)sd SE:(int)se SF:(int)sf SG:(int)sg SH:(int)sh;

/**
 *  page 692.
 *
 *  @param n 64,80
 */
- (void)escTransmitPaperLayoutInformation:(int)n;

/**
 *  page 701.
 *
 *  @param fn (1,49)
 *  @param m  (1,49)
 */
- (void)escSaveSettingValuesFromWorkAreaIntoStorageAreaFN:(int)fn M:(int)m;

/**
 *  page 702
 *
 *  @param fn (2,50)
 *  @param m  (0,1,48,49)
 */
- (void)escLoadSettingValuesStoredInStorageAreaToWorkAreaFN:(int)fn M:(int)m;

/**
 *  page 703
 *
 *  @param fn (3,51)
 *  @param m  (0,1,48,49)
 */
- (void)escSelectSettingValuesLoadedToWorkAreaAfterInitializationProcessFN:(int)fn M:(int)m;

#pragma mark Counter Printing Commands

/**
 *  page 705.
 *
 *  @param n (2~5)
 *  @param m (0~2),(48~50)
 */
- (void)escSelectCounterPrintModeN:(int)n M:(int)m;

/**
 *  page 707
 *
 *  @param counting_moden  (0~255)
 *  @param repetitionr     (0~255)
 */
- (void)escSelectCounterModeA_MinimumValue:(int)minimum_value
                              MaximumValue:(int)maximum_value
                              CountingMode:(int)counting_mode
                                Repetition:(int)repetition;

/**
 *  page 709
 *
 *  @param nl (0~255) default:1
 *  @param nh (0~255) default:0
 */
- (void)escSetCounterN:(int)n;

/**
 *  page 710
 *
 *  @param sa (0~65535)     default:1
 *  @param sb (0~65535)     default:65535
 *  @param sn (0~255)       default:1
 *  @param sr (0~255)       default:1
 *  @param sc (0~65535)     default:1
 */
- (void)escSelectCounterModeB_SA:(int)sa SB:(int)sb SN:(int)sn SR:(int)sr SC:(int)sc;

/**
 *  page 713.
 */
- (void)escPrintCounter;

#pragma mark Printing Paper Commands

/**
 *  page 720.
 */
- (void)escPaperLayoutSettingP:(int)p   SM:(int)sm SA:(int)sa
                            SB:(int)sb SC:(int)sc SD:(int)sd SE:(int)se SF:(int)sf;

/**
 *  page 729.
 *
 *  @param n (74,80)
 */
- (void)escPaperLayoutInformationTransmissionN:(int)n;

/**
 *  page 732.
 *
 *  @param m 48
 */
- (void)escTransmitPositioningInformationM:(int)m;

/**
 *  pag 737.
 *
 *  @param m (48,49)
 */
- (void)escFeedPaperToLabelPeelingPositionM:(int)m;

/**
 *  page 740.
 *
 *  @param m (48,49)
 */
- (void)escFeedPaperToCuttingPositionM:(int)m;

/**
 *  page 742.
 *
 *  @param m (48,49,50)
 */
- (void)escFeedPaperToPrintStartingPositionM:(int)m;

/**
 *  page 744.
 *
 *  @param pl (2,3)
 *  @param ph (0)
 *  @param sn (80)
 */
- (void)escPaperLayoutErrorSpecialMarginSettingP:(int)p SN:(int)sn;

@end
