//
//  HPRTCommandTSPL.h
//  HPRTSDK
//
//  Created by midmirror on 16/2/29.
//  Copyright © 2016年 HPRT. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "HPRTPublicDefine.h"

/**
 *  TSC-TSPL 指令集：大约62个生成指令的函数
 */
@interface HPRTCommandTSPL : NSObject

singletonH(HPRTCommandTSPL)

//初始化指令队列
- (void)initCMDQueue;

//发送指令队列
- (void)sendCMDQueue;

//将生成的位图数据加入打印队列
- (void)addBitmapDataToCMDQueue:(NSData *)data;

/**
 *  自检，打印打印机信息
 */
- (void)selfTest;

/**
 *  打印纸张范围大小
 */
- (void)setPrintAreaSizeWithWidth:(NSString *)label_width
                           Height:(NSString *)label_height;

/**
 *  设置标签纸的间距
 *
 *  @param distance 两张标签紙中间的垂直距离
 *  @param offset   垂直间距的偏移
 */
- (void)setGapWithDistance:(NSString *)distance
                    Offset:(NSString *)offset;

/**
 *  设置黑线
 *
 *  @param height 黑线的高度 0~25.4 mm
 *  @param offset 黑线偏移量 0~label length
 *  height,offset 为0,0表示连续标签
 */
- (void)setBlineWithHeight:(NSString *)height
                    Offset:(NSString *)offset;

/**
 *  走纸
 */
- (void)setOffsetWithDistance:(NSString *)distance;

/**
 *  打印数量
 *
 *  @param sets   多少份       how many sets of labels will be printed.
 *  @param copies 每份多少张    how many copies should be printed for each particular label set.
 */
- (void)printWithSets:(NSString *)sets  Copies:(NSString *)copies;

/**
 *  打印文本
 */
- (void)printTexTWithXPos:(NSString *)x_pos
                     YPos:(NSString *)y_pos
                     Font:(NSString *)font
                 Rotation:(NSString *)rotation
          XMultiplication:(NSString *)x_multiplication
          YMultiplication:(NSString *)y_multiplication
                     Text:(NSString *)text;

/**
 *  清除打印机缓冲区
 */
- (void)setCLS;

/**
 *  打印一维条码
 *
 *  @param type     条码类型 @[128,128M,EAN128,25,25C,39,29S,93,EAN13,EAN13+2,EAN13+5,EAN8,EAN8+5,CODA,POST,UPCA,UPCA+2,UPCA+5,UPCE,UPCE+2,UPCE+5,CPOST,MSI,MSIC,PLESSEY,ITF14,EAN14,11];
 *  @param readable 是否可读：0，不可读，1，可读
 *  @param rotation 旋转：0，90，180，270
 *  @param narrow   窄元素
 *  @param wide     宽元素
 */
- (void)printBarcodeWithXPos:(NSString *)x_pos
                        YPos:(NSString *)y_pos
                        Type:(NSString *)type
                      Height:(NSString *)height
               HumanReadable:(NSString *)readable
                    Rotation:(NSString *)rotation
                      Narrow:(NSString *)narrow
                        Wide:(NSString *)wide
                  CodeNumber:(NSString *)codeNumber;

/**
 *  打印二维条码
 */
- (void)printQRcodeWithXPos:(NSString *)x_pos
                       YPos:(NSString *)y_pos
                   EccLevel:(NSString *)ecc_level
                  CellWidth:(NSString *)width
                       Mode:(NSString *)mode
                   Rotation:(NSString *)rotation
                      Model:(NSString *)model
                       Mask:(NSString *)mask
                       Text:(NSString *)text;

/**
 *  打印位图
 *
 *  @param data   Bitmap data
 *  @param mode   位图模式：（0:OVERWRITE 1:OR 2:XOR）
 */
- (void)printBitmapWithXPos:(NSString *)x_pos
                       YPos:(NSString *)y_pos
                      Width:(NSString *)width
                     Height:(NSString *)height
                       Mode:(NSString *)mode;

#pragma mark BasicSetting 基本设定
//设置打印速度
- (void)setSpeed:(NSString *)speed;

/**
 *  设置打印浓度
 *
 *  @param density 浓度 0~15 level
 */
- (void)setDensity:(NSString *)density;

/**
 *  设置打印的方向和镜像
 *
 *  @param direction 方向，面对打印机，向自己方向出纸，0，左上角，1，右下角
 *  @param mirror    镜像，可选项 0 普通，1 镜像
 */
- (void)setDirection:(NSString *)direction Mirror:(NSString *)mirror;

//设置标签参考起点
- (void)setReferenceXPos:(NSString *)x_pos
                    YPos:(NSString *)y_pos;

/**
 *  设置国际字符集
 7-bit code page name:
 USA: USA
 BRI: British
 GER: German
 FRE: French
 DAN: Danish
 ITA: Italian
 SPA: Spanish
 SWE: Swedish
 SWI: Swiss
 
 8-bit code page number:
 437: United States
 850: Multilingual
 852: Slavic
 860: Portuguese
 863: Canadian/French
 865: Nordic
 857: Turkish (TSPL2 printers only)
 
 Windows code page:
 1250: Central Europe (TSPL2 printers only)
 1252: Latin I (TSPL2 printers only)
 1253: Greek (TSPL2 printers only)
 1254: Turkish (TSPL2 printers only)
 *
 *  @param codepage 字符集代码
 */
- (void)setCodePage:(NSString *)codepage;

//设置标签进纸长度
- (void)setFeedLength:(NSString *)feedLength;

//设置进纸到下一标签起始处
- (void)setFormFeed;

//设置标签定位到内部传感器确定的起点
- (void)setHome;

/**
 *  设置蜂鸣
 *
 *  @param level    0-9
 *  @param interval 1-4095
 */
- (void)setSoundWithLevel:(NSString *)level
                 Interval:(NSString *)interval;

//设置切纸
- (void)setCut;

//设置停止送纸
- (void)setLimitFeed:(NSString *)max_len;

/**
 *  在标签上画一条线
 */
- (void)printBarWithXPos:(NSString *)x_pos
                    YPos:(NSString *)y_pos
                   Width:(NSString *)width
                  Height:(NSString *)height;

/**
 *  在标签上绘制矩形
 *  @param thickness 线宽
 */
- (void)setBoxWithXStart:(NSString *)x_start
                  YStart:(NSString *)y_start
                    XEnd:(NSString *)x_end
                    YEnd:(NSString *)y_end
               Thickness:(NSString *)thickness;

/**
 *  在标签上绘制圆形
 *
 *  @param diameter  直径
 *  @param thickness 线宽
 */
- (void)setCircleWithXStart:(NSString *)x_start
                     YStart:(NSString *)y_start
                   Diameter:(NSString *)diameter
                  Thickness:(NSString *)thickness;

/**
 *  擦除图像缓冲区指定的区域
 */
- (void)setEraseWithXStart:(NSString *)x_start
                    YStart:(NSString *)y_start
                    XWidth:(NSString *)x_width
                   YHeight:(NSString *)y_height;

/**
 *  设置 DataMatrix 二维码，当前仅支持 ECC200 错误纠正
 *
 *  @param xm         [可选]，Module size，x6，x8
 *  @param row        [可选]，范围：10-144
 *  @param col        [可选]，范围：10-144
 *  @param expression 表达式
 */
- (void)setDmatrixWithExpression:(NSString *)expression
                            XPos:(NSString *)x_pos
                            YPos:(NSString *)y_pos
                           Width:(NSString *)width
                          Height:(NSString *)height
                              XM:(NSString *)xm
                             Row:(NSString *)row
                             Col:(NSString *)col;

/**
 *  打印 Maxicode 二维码
 *
 *  @param mode    2,3,4,5
 *  @param class   [option],Class of Service ,3-digit number(for mode 2,3)
 *  @param country [option],Country code, 3-digit number (for mode 2,3)
 *  @param post    [option],
 Mode 2: (USA) 5-digit+ 4-digit number.
 Mode 3: (Canada) 6 alphanumeric post code included by double quotes.
 *  @param lm      Expression length (double quote is ignored) , 范围：1-138, (this parameter is just for mode 4 and 5.)
 */
- (void)setMaxicode:(NSString *)text
               XPos:(NSString *)x_pos
               YPos:(NSString *)y_pos
               Mode:(NSString *)mode
              Class:(NSString *)iClass
            Country:(NSString *)country
               Post:(NSString *)post
                 LM:(NSString *)lm;

/**
 *
 
 [Option]
 
 P  Data compression method
 0: Auto encoding
 1: Binary mode
 
 E  Error correction level. Range: 0~8 Center pattern in barcode area
 0: The pattern will print upper left justified the area
 1: The pattern is printed middle of area
 
 Ux,y,c Human readable
 x: Human readable characters in the specified x-coordinate
 y: Human readable characters in the specified y-coordinate
 c: Maximum characters of human readable character per line
 
 W  Module width in dot. Range: 2~9
 H  Bar height in dot. Range: 4~99
 R  Maximum number of rows
 C  Maximum number of columns
 T  Truncation.
 0: Not truncated
 1: Truncated
 
 *  @param option 可选项
 */
- (void)printPDF417WithXPos:(NSString *)x_pos
                       YPos:(NSString *)y_pos
                      Width:(NSString *)width
                     Height:(NSString *)height
                     Rotate:(NSString *)rotate
                     Option:(NSString *)option
                 Expression:(NSString *)expression;

/**
 *  print Bitmap format image.
 */
- (void)putBMPWithFilename:(NSString *)filename
                      XPos:(NSString *)x_pos
                      YPos:(NSString *)y_pos;

- (void)putPCXWithFilename:(NSString *)filename
                      XPos:(NSString *)x_pos
                      YPos:(NSString *)y_pos;

- (void)setReverseWithXStart:(NSString *)x_start
                      YStart:(NSString *)y_start
                      XWidth:(NSString *)x_width
                     YHeight:(NSString *)y_height;

- (void)getStatus;

#pragma mark Device Reconfiguration Commands

/**
 *  计数器设置
 *
 *  @param counterNumber 第几个计数器 （0-50）
 *  @param step          计数间隔    （-99999999 ~ 99999999）
 */
- (void)setCounterWithCounterNumber:(NSString *)counterNumber
                               Step:(NSString *)step;

- (void)setCutterON;
- (void)setCutterOFF;
- (void)setCutterBATCH;

/**
 *  set number of printing labels per cut
 *
 *  @param pieces (0 ~ 65535)
 */
- (void)setCutterPieces:(NSString *)pieces;

- (void)setPARTIAL_CUTTER_OFF;
- (void)setPARTIAL_CUTTER_BATCH;

/**
 *  set number of printing labels per cut
 *
 *  @param pieces (0 ~ 65535)
 */
- (void)setPARTIAL_CUTTER_Pieces:(NSString *)pieces;

- (void)setBackOFF;
- (void)setBackON;

/**
 *  This setting is used to enable/disable the KEY1/KEY2/KEY3 function.
 *
 *  @param index    KEY1,KEY2,KEY3
 *  @param switcher ON/OFF
 */
- (void)setKEY:(int)index Switch:(NSString *)switcher;

/**
 *  This setting is used to enable/disable the LED function.
 LED1 Power on/off
 LED2 Printer on-line/off-line
 LED3 Error/normal
 *
 *  @param index    LED1,LED2,LED3
 *  @param switcher ON/OFF
 */
- (void)setLED:(int)index Switch:(NSString *)switcher;

- (void)setPeelON;
- (void)setPeelOFF;

/**
 *  This command is used to enable/disable feeding of labels to gap/black mark position for tearing off.
 *  This setting will be saved in printer memory when turning off the power.
 */
- (void)setTearON;
- (void)setTearOFF;

- (void)setStriperON;
- (void)setStriperOFF;

/**
 *  This setting is used to enable/disable head open sensor.
 */
- (void)setHeadON;
- (void)setHeadOFF;

- (void)setRibbonON;
- (void)setRibbonOFF;

/**
 *  This setting defines communication parameters for printer serial port.
 *
 *  @param baud   24,48,96,19,38,57,115( 对应单位2400 bps,4800 bps,9600 bps,38400 bps,15200 bps)
 *  @param parity N,E,O(NO/Even/Odd parity check)
 *  @param data   7,8(bits Data)
 *  @param stop   1,2(stop bit)
 */
- (void)setCOM1WithBaud:(NSString *)baud
                 Parity:(NSString *)parity
                   Data:(NSString *)data
                   Stop:(NSString *)stop;

/**
 *  This command will print one label and feed label gap to tear br position for tearing away.
 *  This setting will be saved in printer memory.
 *
 *  @param key OFF/ON/AUTO/<num>
 */
- (void)setPrintKey:(NSString *)key;

- (void)setReprintON;
- (void)setReprintOFF;

@end
